@@ -1,25 +1,12 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Zasebno",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Vidno le uporabnikom povezanimi s programom Talk prek telefonske številke.",
-    "Local" : "Krajevno",
-    "Only visible to people on this instance and guests" : "Vidno le krajevnim uporabnikom in povezanim gostom",
-    "Federated" : "Zvezno",
-    "Only synchronize to trusted servers" : "Usklajuj le z zaupanja vrednimi strežniki",
-    "Published" : "Objavljeno",
-    "Synchronize to trusted servers and the global and public address book" : "Usklajuj z varnimi strežniki in splošnimi in javnimi imeniki",
-    "Verify" : "Overi",
-    "Verifying …" : "Poteka overjanje ...",
     "Unable to change password" : "Ni mogoče spremeniti gesla",
     "Very weak password" : "Zelo šibko geslo",
     "Weak password" : "Slabo geslo",
     "So-so password" : "Šibko geslo",
     "Good password" : "Dobro geslo",
     "Strong password" : "Odlično geslo",
-    "Groups" : "Skupine",
-    "Group list is empty" : "Seznam skupin je prazen",
-    "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
     "{actor} added you to group {group}" : "{actor} vas doda v skupino {group}",
     "You added {user} to group {group}" : "Uporabnika {user} dodate v skupino {group}",
     "{actor} added {user} to group {group}" : "{actor} doda uporabnika {user} v skupino {group}",
@@ -104,13 +91,11 @@ OC.L10N.register(
     "Set your password" : "Določitev gesla",
     "Go to %s" : "Odpri oblak %s",
     "Install Client" : "Namesti odjemalca",
-    "Logged in account must be a subadmin" : "Račun prijave mora imeti dovoljenja podpornega skrbnika",
     "Apps" : "Programi",
     "Personal" : "Osebno",
     "Administration" : "Skrbništvo",
     "Users" : "Uporabniki",
     "Additional settings" : "Dodatne nastavitve",
-    "Artificial Intelligence" : "Umetna inteligenca",
     "Administration privileges" : "Skrbniška dovoljenja",
     "Groupware" : "Skupinsko delo",
     "Overview" : "Splošni pregled",
@@ -120,10 +105,13 @@ OC.L10N.register(
     "Calendar" : "Koledar",
     "Personal info" : "Osebni podatki",
     "Mobile & desktop" : "Mobilni in namizni dostop",
+    "Artificial Intelligence" : "Umetna inteligenca",
     "Email server" : "Poštni strežnik",
     "Background jobs" : "Opravila v ozadju",
     "Unlimited" : "Neomejeno",
     "Verifying" : "Preverjanje",
+    "Verifying …" : "Poteka overjanje ...",
+    "Verify" : "Overi",
     "Allowed admin IP ranges" : "Dovoljeni skrbniški obsegi naslovov IP",
     "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Nastavitveni ključ »%1$s« zahteva podatkovno polje (zaznano je %2$s). Skrbniško preverjanje obsega naslovov IP ne bo uveljavljeno.",
     "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Nastavitveni ključ »%1$s« vsebuje neveljaven obseg naslovov IP: »%2$s«",
@@ -227,7 +215,6 @@ OC.L10N.register(
     "HTTP headers" : "Glave HTTP",
     "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "– Glava HTTP »%1$s« ni nastavljena na pričakovano vrednost »%2$s«. Nekatere možnosti morda ne bodo delovale pravilno, zato je priporočljivo prilagoditi nastavitve.",
     "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "– Glava HTTP »%1$s« ni nastavljena na pričakovano vrednost »%2$s«. To predstavlja potencialno varnostno ali zasebnostno tveganje, zato je priporočljivo prilagoditi nastavitve.",
-    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "– Glava HTTP »%1$s« ne vključuje vrednosti »%2$s«. To predstavlja potencialno varnostno ali zasebnostno tveganje, zato je priporočljivo prilagoditi nastavitve.",
     "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "– Glava HTTP »%1$s« ni nastavljena na »%2$s«, »%3$s«, »%4$s«, »%5$s« ali »%6$s«. To la hko povzroči spuščanje sklicnih podatkov. Več o tem je zapisano na {w3c-recommendation}.",
     "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "– Glava HTTP za varen prenos podatkov »Strict-Transport-Security« ni nastavljena na vsaj »%d« sekund (trenutna vrednost je »%d«). Za večjo varnost je priporočljivo omogočiti pravila HSTS.",
     "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "– Glava HTTP za varen prenos podatkov »Strict-Transport-Security« je neustrezno oblikovana: »%s«. Za večjo varnost je priporočljivo omogočiti pravila HSTS.",
@@ -244,13 +231,13 @@ OC.L10N.register(
     "Profile information" : "Podrobnosti profila",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Slika profila, polno ime, elektronski naslov, telefonska številka, naslov, spletna stran, račun Twitter, ustanova, vloga, naslov, biografija in ali je profil omogočen.",
     "Nextcloud settings" : "Nastavitve Nextcloud",
-    "Task:" : "Naloga:",
     "Enable" : "Omogoči",
     "Machine translation" : "Strojno prevajanje",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Strojno prevajanje lahko izvajajo različni programi. Na tem mestu je mogoče določiti prednost uporabe programov za strojno prevajanje, ki so trenutno nameščeni v sistem.",
     "Image generation" : "Ustvarjanje slik",
     "Text processing" : "Obdelava besedila",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Obdelavo besedila lahko urejajo različni programi. Na tem mestu je mogoče določiti program za uporabo.",
+    "Task:" : "Naloga:",
     "Here you can decide which group can access certain sections of the administration settings." : "Na tem mestu je mogoče določiti, katera skupina ima dostop do določenih možnosti skrbniških nastavitev.",
     "Unable to modify setting" : "Ni mogoče spremeniti nastavitve",
     "None" : "Brez",
@@ -273,8 +260,6 @@ OC.L10N.register(
     "Set default expiration date for shares to other servers" : "Nastavi privzeti datuma poteka za mesta souporabe na drugih strežnikih",
     "Default expiration time of shares in days" : "Privzeti čas poteka za mesta souporabe v dnevih",
     "Privacy settings for sharing" : "Nastavitve zasebnosti za souporabo",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Če je omogočeno samodejno dopolnjevanje »v isti skupini«, ali pa »po telefonskem imeniku«, se zadetek pokaže, če je uporabnik v katerikoli od teh zbirk.",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Dovoli samodejno dokončanje pri vnosu polnega imena ali elektronskega naslova (brez upoštevanja manjkajočega ujemanja s telefonskim imenikom in pripadnosti isti skupini)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Pokaži izjavo o omejitvi odgovornosti pri uporabi javnih povezav za pošiljanje (če je onemogočen prikaz seznama datotek)",
     "Disclaimer text" : "Besedilo o omejitvi odgovornosti",
     "This text will be shown on the public link upload page when the file list is hidden." : "Besedilo izjave o omejitvi odgovornosti, ki bo izpisano v oknu za pošiljanje, ko je možnost prikaza seznama datotek onemogočena.",
@@ -288,6 +273,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Dvo-stopenjsko overjanje ni obvezno za člane navedenih skupin.",
     "Excluded groups" : "Izločene skupine",
     "Save changes" : "Shrani spremembe",
+    "Default" : "Privzeto",
     "Show details for {appName} app" : "Pokaži podrobnosti programa {appName}",
     "Update to {update}" : "Posodobi na različico {update}",
     "Remove" : "Odstrani",
@@ -307,6 +293,13 @@ OC.L10N.register(
     "No apps found for your version" : "Za navedeni iskalni niz ni programov",
     "_%n app has an update available_::_%n apps have an update available_" : ["Na voljo je posodobitev za %n program.","Na voljo sta posodobitvi za %n programa.","Na voljo so posodobitve za %n programe.","Na voljo so posodobitve za %n programov."],
     "_Update_::_Update all_" : ["Posodobi","Posodobi","Posodobi","Posodobi vse"],
+    "Failed to create group" : "Ustvarjanje skupine je spodletelo",
+    "Groups" : "Skupine",
+    "Creating group…" : "Poteka ustvarjanje skupine ...",
+    "Create group" : "Ustvari skupino",
+    "Group name" : "Ime skupine",
+    "Please enter a valid group name" : "Vpisati je treba veljavno ime skupine",
+    "Loading groups…" : "Poteka nalaganje skupin ...",
     "Could not load app discover section" : "Ni mogoče naložiti razdelka predstavitve programov",
     "Could not render element" : "Predmeta ni mogoče izrisati",
     "Nothing to show" : "Ni vsebine za prikaz",
@@ -328,12 +321,10 @@ OC.L10N.register(
     "Admin documentation" : "Skrbniška dokumentacija",
     "Developer documentation" : "Dokumentacija za razvijalce",
     "Details" : "Podrobnosti",
-    "All" : "Vsi",
+    "All" : "Vse",
     "Limit app usage to groups" : "Omeji uporabo programa na skupine",
     "No results" : "Ni zadetkov",
     "Update to {version}" : "Posodobi na različico {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcoud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerazrešenih odvisnosti:",
     "Latest updated" : "Nazadnje posodobljeno",
     "Author" : "Avtor",
@@ -415,12 +406,9 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : " Upoštevajte, da šifriranje poveča velikost datoteke.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Priporočljivo je redno ustvarjati varnostne kopije podatkov, v primeru šifriranja pa varnostno kopirati tudi šifrirne ključe.",
     "This is the final warning: Do you really want to enable encryption?" : "To je zadnje opozorilo. Ali res želite omogočiti šifriranje?",
-    "Failed to remove group \"{group}\"" : "Odstranjevanje skupine »{group}« je spodlotelo",
     "Please confirm the group removal" : "Potrditi je treba skupinsko odstranjevanje",
-    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "Odstranili boste skupino »{group}«. Računi ne bodo izbrisani.",
     "Submit" : "Pošlji",
     "Rename group" : "Preimenuj skupino",
-    "Remove group" : "Odstrani skupino",
     "Current password" : "Trenutno geslo",
     "New password" : "Novo geslo",
     "Change password" : "Spremeni geslo",
@@ -442,6 +430,9 @@ OC.L10N.register(
     "Enter your date of birth" : "Vpišite datum rojstva",
     "You are a member of the following groups:" : "Omogočeno je članstvo v skupinah:",
     "Your full name" : "Polno ime",
+    "Unable to update primary email address" : "Ni mogoče posodobiti osnovnega elektronskega naslova",
+    "Unable to delete additional email address" : "Ni mogoče izbrisati dodatnega elektronskega naslova",
+    "No email address set" : "Poštni naslov ni nastavljen",
     "Email options" : "Možnosti elektronske pošte",
     "Options for additional email address {index}" : "Dodatni elektronski naslov {index}",
     "Remove primary email" : "Odstrani osnovni elektronski naslov",
@@ -451,22 +442,19 @@ OC.L10N.register(
     "Set as primary email" : "Nastavi kot osnovni elektronski naslov",
     "Additional email address {index}" : "Dodatni elektronski naslov {index}",
     "Unable to delete primary email address" : "Ni mogoče izbrisati osnovnega elektronskega naslova",
-    "Unable to update primary email address" : "Ni mogoče posodobiti osnovnega elektronskega naslova",
     "Unable to add additional email address" : "Ni mogoče dodati dodatnega elektronskega naslova",
     "Unable to update additional email address" : "Ni mogoče posodobiti dodatnega elektronskega naslova",
-    "Unable to delete additional email address" : "Ni mogoče izbrisati dodatnega elektronskega naslova",
     "Primary email for password reset and notifications" : "Osnovni elektronski naslov za obnavljanje gesla in obvestila",
-    "No email address set" : "Poštni naslov ni nastavljen",
     "Your handle" : "Ročnik",
     "Your headline" : "Vaš naslov",
+    "No language set" : "Jezik ni nastavljen",
     "Unable to update language" : "Ni mogoče posodobiti jezika",
     "Languages" : "Jeziki",
     "Help translate" : "Sodelujte pri prevajanju",
-    "No language set" : "Jezik ni nastavljen",
+    "No locale set" : "Ni določenih jezikovnih nastavitev",
     "Unable to update locale" : "Ni mogoče posodobiti jezikovnih nastavitev",
     "Locales" : "Jezikovne nastavitve",
     "Week starts on {firstDayOfWeek}" : "Prvi dan tedna je {firstDayOfWeek}",
-    "No locale set" : "Ni določenih jezikovnih nastavitev",
     "Your city" : "Kraj bivanja",
     "Your organisation" : "Ustanova",
     "Your phone number" : "Osebna telefonska številka",
@@ -475,6 +463,7 @@ OC.L10N.register(
     "Enable profile" : "Omogoči profil",
     "Unable to update visibility of {displayId}" : "Ni mogoče posodobiti vidnosti {displayId}",
     "Your role" : "Vloga",
+    "Timezone" : "Časovni pas",
     "Your X (formerly Twitter) handle" : "Osebni ročnik X (prej Twitter)",
     "Your website" : "Osebna spletna stran",
     "Invalid value" : "Neveljavna vrednost",
@@ -485,16 +474,16 @@ OC.L10N.register(
     "Unable to update federation scope of additional {property}" : "Ni mogoče posodobiti obsega zveznosti nadaljnjih lastnosti {property}",
     "Add additional email" : "Dodaj dodaten elektronski naslov",
     "Add" : "Dodaj",
-    "Create" : "Ustvarjanje",
+    "Create" : "Ustvari",
     "Change" : "Spreminjanje",
-    "Delete" : "Brisanje",
+    "Delete" : "Izbriši",
     "Reshare" : "Nadaljnja souporaba",
+    "School" : "Šola",
     "Default language" : "Privzeti jezik",
     "Common languages" : "Splošni jeziki",
     "Other languages" : "Drugi jeziki",
     "Password change is disabled because the master key is disabled" : "Spreminjanje gesla je onemogočeno, ker je onemogočen tudi glavni šifrirni ključ",
     "No accounts" : "Ni računov",
-    "Loading accounts …" : "Poteka nalaganje računov ...",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Seznam računov. Seznam zaradi zmogljivosti sistema ni v celoti prikazan. Podatki uporabnikov se nalagajo med pomikanjem po seznamu.",
     "Manager" : "Upravljalnik",
     "Account name will be autogenerated" : "iME RAČUNA bo samodejno ustvarjeno",
@@ -508,13 +497,11 @@ OC.L10N.register(
     "Member of the following groups" : "Član navedenih skupin",
     "Set account groups" : "Nastavi skupine računov",
     "Admin of the following groups" : "Skrbnik navedenih skupin",
-    "Set account as admin for …" : "Nastavi račun kot skrbniški za ...",
     "Quota" : "Količinska omejitev",
     "Set account quota" : "Nastavi količinsko omejitev računa",
     "Language" : "Jezik",
     "Set default language" : "Nastavi privzeti jezik",
     "Add new account" : "Dodaj nov račun",
-    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} račun ...","{userCount} računa ...","{userCount} računi ...","{userCount} računov ..."],
     "_{userCount} account_::_{userCount} accounts_" : ["{userCount} račun ...","{userCount} računa ...","{userCount} računi ...","{userCount} računov ..."],
     "Total rows summary" : "Skupni povzetek vrstic",
     "Scroll to load more rows" : "Podrsajte za nalaganje več vrstic",
@@ -532,7 +519,6 @@ OC.L10N.register(
     "Disable account" : "Onemogoči račun",
     "Enable account" : "Omogoči račun",
     "Resend welcome email" : "Ponovno pošlji potrditveno sporočilo",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Možnost omogoča varnostno brisanje podatkov Nextcloud z vseh naprav, povezanih z uporabniškim računom {userid}. Možnost deluje le, če so naprave povezane v spletno omrežje. Brisanje z oddaljenih naprav je uporabno v primeru izgubljene naprave, ali na primer prekinitve sodelovanja v neki skupini.",
     "Remote wipe of devices" : "Oddaljeno varnostno brisanje naprav",
     "Wipe {userid}'s devices" : "Varnostno izbriši naprave uporabniškega računa {userid}",
     "Wiped {userid}'s devices" : "Varnostno izbrisane naprave računa {userid}",
@@ -543,7 +529,6 @@ OC.L10N.register(
     "Password was successfully changed" : "Geslo je uspešno spremenjeno",
     "Email was successfully changed" : "Elektronski naslov je uspešno spremenjen",
     "Welcome mail sent!" : "Potrditveno sporočilo je poslano!",
-    "Loading account …" : "Poteka nalaganje računa ...",
     "Change display name" : "Spremeni prikazno ime",
     "Set new password" : "Nastavi novo geslo",
     "You do not have permissions to see the details of this account" : "Ni ustreznih dovoljenj za pregled podrobnosti tega računa",
@@ -574,13 +559,16 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Brezgeselna overitev zahteva varno povezavo.",
     "Add WebAuthn device" : "Dodaj napravo WebAuthn",
     "Please authorize your WebAuthn device." : "Overite napravo WebAuthn",
-    "Adding your device …" : "Poteka dodajanje naprave ..",
     "Unnamed device" : "Neimenovana naprava",
     "Passwordless Authentication" : "Brezgeselna overitev",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Nastavitev račun za brezgeselno overitev dostopa po standardu FIDO2.",
     "No devices configured." : "Ni nastavljenih naprav.",
     "The following devices are configured for your account:" : "Z vašim računom so povezane navedene naprave:",
     "Your browser does not support WebAuthn." : "Brskalnik ne podpira overitve WebAuthn.",
+    "Security & setup warnings" : "Varnost in namestitvena opozorila",
+    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
+    "There are some errors regarding your setup." : "Med preverjanjem je bilo zaznanih nekaj napak namestitve.",
+    "There are some warnings regarding your setup." : "Med preverjanjem je bilo zbranih nekaj opozoril.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Skrbnik lahko prilagodi možnosti souporabe. Več podrobnosti je zapisanih v dokumentaciji.",
     "You need to enable the File sharing App." : "Omogočiti je treba program Souporabe datotek.",
     "App Store" : "Programska trgovina",
@@ -588,15 +576,11 @@ OC.L10N.register(
     "Loading categories" : "Poteka nalaganje kategorij",
     "Developer documentation ↗" : "Dokumentacija za razvijalce ↗",
     "Version {version}, {license}-licensed" : "Različica {version}, z dovoljenjem {license}",
+    "Apply" : "Uveljavi",
     "All accounts" : "Vsi računi",
     "Admins" : "Skrbniki",
     "Account group: {group}" : "Skupina računov: {group}",
-    "Failed to create group" : "Ustvarjanje skupine je spodletelo",
     "Account management" : "Upravljanje z računi",
-    "Creating group…" : "Poteka ustvarjanje skupine ...",
-    "Create group" : "Ustvari skupino",
-    "Group name" : "Ime skupine",
-    "Please enter a valid group name" : "Vpisati je treba veljavno ime skupine",
     "Sending…" : "Poteka pošiljanje ...",
     "Email sent" : "Elektronsko sporočilo je poslano",
     "Location" : "Trenutno mesto",
@@ -615,6 +599,14 @@ OC.L10N.register(
     "Profile visibility" : "Vidnost profila",
     "Locale" : "Jezikovne nastavitve",
     "First day of week" : "Prvi dan tedna",
+    "Private" : "Zasebno",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Vidno le uporabnikom povezanimi s programom Talk prek telefonske številke.",
+    "Local" : "Krajevno",
+    "Only visible to people on this instance and guests" : "Vidno le krajevnim uporabnikom in povezanim gostom",
+    "Federated" : "Zvezno",
+    "Only synchronize to trusted servers" : "Usklajuj le z zaupanja vrednimi strežniki",
+    "Published" : "Objavljeno",
+    "Synchronize to trusted servers and the global and public address book" : "Usklajuj z varnimi strežniki in splošnimi in javnimi imeniki",
     "Discover" : "Predstavitve",
     "Your apps" : "Vsi programi",
     "Active apps" : "Zagnani programi",
@@ -630,7 +622,6 @@ OC.L10N.register(
     "Disable" : "Onemogoči",
     "Allow untested app" : "Omogoči nepreizkušen program",
     "The app will be downloaded from the App Store" : "Program bo prejet iz zbirke programov",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta program ni označen kot skladen z nameščeno različico oblaka Nextcloud. Če nameravate nadaljevati, boste program lahko namestili, vendar ta morda ne bo deloval po pričakovanjih, ali pa bo vplival na stabilnost sistema.",
     "Unknown" : "Neznano",
     "Never" : "Nikoli",
     "Could not register device: Network error" : "Naprave ni mogoče vpisati: napaka omrežja",
@@ -671,14 +662,6 @@ OC.L10N.register(
     "SMTP Password" : "Geslo SMTP",
     "Save" : "Shrani",
     "Test and verify email settings" : "Preizkusi in overi nastavitve elektronske pošte",
-    "Security & setup warnings" : "Varnost in namestitvena opozorila",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je nujno, da je sistem posodobljen in pravilno nastavljen. Preverjanje poteka tako, da se nekateri preizkusi izvajajo sproti in samodejno. Več podrobnosti je zabeleženih v dokumentaciji. ",
-    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
-    "There are some errors regarding your setup." : "Med preverjanjem je bilo zaznanih nekaj napak namestitve.",
-    "There are some warnings regarding your setup." : "Med preverjanjem je bilo zbranih nekaj opozoril.",
-    "Checking for system and security issues." : "Preverjanje sistemskih in varnostnih nastavitev.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Preverite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">namestitveno dokumentacijo ↗</a> in morebitne napake oziroma opozorila v <a href=\"%2$s\">sistemskem dnevniku</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Preverite lahko tudi varnost storitev Nextcloud s <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">preverjalnikom ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Razlogi za uporabo oblaka Nextcloud v vaši organizaciji",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Okolje razvija {communityopen}skupnost Nextcloud{linkclose}, {githubopen}izvorna koda{linkclose} pa je objavljena pod pogoji dovoljenja {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Spremljajte naš Facebook",
@@ -689,45 +672,22 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ta objava oblaka Nextcloud ne vključuje podpore in hipna obvestila niso na voljo.",
     "Use a second factor besides your password to increase security for your account." : "Ob geslu je priporočljivo uporabiti tudi drugo-stopenjsko overitev za večjo varnost računa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Če uporabljate za povezavo z oblakom Nextcloud programe tretjih oseb, najprej ustvarite in nastavite gesla za vsak program, preden omogočite dvostopenjsko overitev.",
-    "Missing optional index \"%s\" in table \"%s\"." : "Manjka izbirno kazalo »%s« v razpredelnici »%s«.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "V podatkovni zbirki ni določenih nekaterih določil. Ker je dodajanje določil na velikih razpredelnicah časovno izredno zahtevno opravilo, ta niso dodana samodejno. Z ukazom »occ db: add-missing-indices« je določila mogoče varno dodati ročno, medtem ko je sistem v delovanju. Po dodajanju bo izvajanje poizvedb teh razpredelnic neprimerno hitrejše.",
-    "File locking" : "Zaklepanje datotek",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Zaklepanje datotek je onemogočeno, kar lahko privede do različnih težav. V izogib zapletom je priporočljivo omogočiti možnost »filelocking.enabled« v datoteki config.php.",
-    "The PHP memory limit is below the recommended value of %s." : "Omejitev pomnilnika PHP je pod priporočeno mejo %s.",
-    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Trenutno je nameščena različica PHP %s. Podpora PHP 8.0 je z različico programa Nextcloud 27 opuščena. Za okolje Nextcloud 28 je zahtevana vsaj podpora PHP 8.1. Priporočena je nadgradnja na uradno podprte različice PHP, ki jih zagotavlja skupnost.",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "V uporabi je različica podatkovne zbirke MariaDB »%s«. Z namestitvijo Nextcloud 21 ta ni več podprta. Sistem zahteva nadgradnjo zbirke na različico MariaDB 10.2 ali višjo.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "V uporabi je različica podatkovne zbirke MySQL »%s«. Z namestitvijo Nextcloud 21 ta ni več podprta. Sistem zahteva nadgradnjo zbirke na različico MySQL 8.0, MariaDB 10.2 ali višje.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "V uporabi je različica podatkovne zbirke PostgreSQL »%s«. Z namestitvijo Nextcloud 21 ta ni več podprta. Sistem zahteva nadgradnjo zbirke na različico PostgreSQL 9.6 ali višjo.",
-    "Speech-To-Text" : "Govor-v-besedilo",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Prepisovanje govora v besedilo lahko izvajajo različni programi. Na tem mestu je mogoče določiti program za uporabo.",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "Noben od trenutno nameščenih programov ne omogoča prepisovanja govora v besedilo.",
-    "None of your currently installed apps provide Text processing functionality" : "Noben od trenutno nameščenih programov ne omogoča obdelave besedila.",
-    "Set default expiration date for shares" : "Nastavi privzeti datuma poteka za mesta souporabe",
-    "Allow username autocompletion in share dialog and allow access to the system address book" : "Omogočite samodejno dokončanje uporabniškega imena v pogovornih oknih za souporabo in omogočite dostop do sistemskega imenika.",
-    "Your biography" : "Biografija",
-    "You are using <strong>{usage}</strong>" : "Uporabljate <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Uporabljate <strong>{usage}</strong> od <strong>{totalSpace}</strong> (<strong>{usageRelative} %</strong>)",
-    "Set user manager" : "Nastavi upravljalnik uporabnikov",
-    "Username will be autogenerated" : "Uporabniško ime bo samodejno ustvarjeno",
-    "Username (required)" : "Uporabniško ime (zahtevano)",
-    "New user" : "Nov uporabnik",
-    "Groups (required)" : "Skupine (zahtevano)",
-    "Set user groups" : "Nastavi uporabniške skupine",
-    "Administered groups" : "Upravljane skupine",
-    "Set user as admin for …" : "Nastavi uporabnika kot skrbnika za ...",
-    "Set user quota" : "Določi količinsko omejitev",
-    "Add new user" : "Dodaj uporabnika",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} uporabnik …","{userCount} uporabnika …","{userCount} uporabniki …","{userCount} uporabnikov …"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} uporabnik","{userCount} uporabnika","{userCount} uporabniki","{userCount} uporabnikov"],
-    "Loading users …" : "Poteka nalaganje uporabnikov ...",
-    "Username" : "Uporabniško ime",
-    "User backend" : "Uporabniški ozadnji program",
-    "User actions" : "Dejanja uporabnika",
-    "Add user to group" : "Dodaj uporabnika v skupino",
-    "Server error while trying to add WebAuthn device" : "Prišlo je do strežniške napake med dodajanjem naprave WebAuthn",
-    "Name your device" : "Naziv naprave",
-    "Active accounts" : "Dejavni računi",
-    "Follow us on Twitter" : "Sledite nam na Twitter!",
-    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Če želite omogočiti izvajanje tega preverjanja, je treba zagotoviti, da se spletni strežnik lahko poveže sam s seboj. Zato mora biti nastavljen za povezovanje z vsaj eno od določenih »varnih domen« (trusted_domains) ali naslovov za prepis »vmesnika ukazne vrstice« (overwrite.cli.url). Spodletelo preverjanje je lahko posledica neujemanja imen DNS na strani strežnika oziroma pravila požarnega zidu."
+    "Group list is empty" : "Seznam skupin je prazen",
+    "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
+    "Logged in account must be a subadmin" : "Račun prijave mora imeti dovoljenja podpornega skrbnika",
+    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "– Glava HTTP »%1$s« ne vključuje vrednosti »%2$s«. To predstavlja potencialno varnostno ali zasebnostno tveganje, zato je priporočljivo prilagoditi nastavitve.",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcoud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
+    "Loading accounts …" : "Poteka nalaganje računov ...",
+    "Set account as admin for …" : "Nastavi račun kot skrbniški za ...",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} račun ...","{userCount} računa ...","{userCount} računi ...","{userCount} računov ..."],
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Možnost omogoča varnostno brisanje podatkov Nextcloud z vseh naprav, povezanih z uporabniškim računom {userid}. Možnost deluje le, če so naprave povezane v spletno omrežje. Brisanje z oddaljenih naprav je uporabno v primeru izgubljene naprave, ali na primer prekinitve sodelovanja v neki skupini.",
+    "Loading account …" : "Poteka nalaganje računa ...",
+    "Adding your device …" : "Poteka dodajanje naprave ..",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta program ni označen kot skladen z nameščeno različico oblaka Nextcloud. Če nameravate nadaljevati, boste program lahko namestili, vendar ta morda ne bo deloval po pričakovanjih, ali pa bo vplival na stabilnost sistema.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je nujno, da je sistem posodobljen in pravilno nastavljen. Preverjanje poteka tako, da se nekateri preizkusi izvajajo sproti in samodejno. Več podrobnosti je zabeleženih v dokumentaciji. ",
+    "Checking for system and security issues." : "Preverjanje sistemskih in varnostnih nastavitev.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Preverite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">namestitveno dokumentacijo ↗</a> in morebitne napake oziroma opozorila v <a href=\"%2$s\">sistemskem dnevniku</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Preverite lahko tudi varnost storitev Nextcloud s <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">preverjalnikom ↗</a>."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
