@@ -206,12 +206,18 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Das Update ist fehlgeschlagen. Bitte melde dieses Problem an die <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud Community</a>.",
     "Continue to {productName}" : "Fortfahren zu {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet.","Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet."],
+    "Done" : "Erledigt",
+    "Scan QR code to log in" : "QR-Code zum Anmelden scannen",
+    "Use {productName} mobile client you want to connect to scan the code" : "Den mobilen {productName}-Client wählen, der zum Scannen des Codes verwendet werden soll",
+    "Code will expire {timeCountdown} or after use" : "Der Code läuft bei Verwendung oder nach {timeCountdown} ab",
     "Applications menu" : "Anwendungs-Menü",
     "Apps" : "Apps",
     "More apps" : "Weitere Apps",
     "_{count} notification_::_{count} notifications_" : ["{count} Benachrichtigung","{count} Benachrichtigungen"],
     "No" : "Nein",
     "Yes" : "Ja",
+    "App password" : "App-Passwort",
+    "Grant access" : "Zugriff gewähren",
     "The remote URL must include the user." : "Die entfernte URL muss den Benutzer enthalten.",
     "Invalid remote URL." : "Ungültige entfernte URL.",
     "Failed to add the public link to your Nextcloud" : "Der öffentliche Link konnte nicht zu deiner Nextcloud hinzugefügt werden",
@@ -248,12 +254,13 @@ OC.L10N.register(
     "Results" : "Ergebnisse",
     "Load more results" : "Weitere Ergebnisse laden",
     "Search in" : "Suche in",
+    "Partial matches" : "Teilübereinstimmungen",
     "Log in" : "Anmelden",
     "Logging in …" : "Melde an …",
     "Log in to {productName}" : "Anmelden bei {productName}",
     "Wrong login or password." : "Kontoname oder Passwort falsch",
     "This account is disabled" : "Dieses Konto ist deaktiviert",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Es wurden mehrere ungültige Anmeldeversuche von deiner IP-Adresse festgestellt. Daher wird die nächste Anmeldung um 30 Sekunden verzögert.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Zu viele falsche Anmeldeversuche. Bitte in 30 Sekunden erneut versuchen.",
     "Account name or email" : "Kontoname oder E-Mail-Adresse",
     "Account name" : "Name des Kontos",
     "Server side authentication failed!" : "Serverseitige Authentifizierung fehlgeschlagen!",
@@ -295,6 +302,13 @@ OC.L10N.register(
     "Skip" : "Überspringen",
     "Installing apps …" : "Installiere Apps …",
     "Install recommended apps" : "Empfohlene Apps installieren",
+    "Online" : "Online",
+    "Away" : "Abwesend",
+    "Busy" : "Beschäftigt",
+    "Do not disturb" : "Bitte nicht stören",
+    "Mute all notifications" : "Alle Benachrichtigungen stummschalten",
+    "Invisible" : "Unsichtbar",
+    "Appear offline" : "Offline erscheinen",
     "Avatar of {displayName}" : "Avatar von {displayName}",
     "Settings menu" : "Einstellungen-Menü",
     "Loading your contacts …" : "Lade deine Kontakte …",
@@ -319,6 +333,14 @@ OC.L10N.register(
     "Back" : "Zurück",
     "Login form is disabled." : "Das Anmeldeformular ist deaktiviert.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Das Nextcloud-Anmeldeformular ist deaktiviert. Nutze ggf. eine andere Anmeldemöglichkeit oder wende dich an deine Administration.",
+    "Connect to your account" : "Verbinde dich mit deinem Konto",
+    "Security warning" : "Sicherheitswarnung",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Solltest du aktuell nicht versuchen, ein neues Gerät oder eine neue App einzurichten, dann kann es sein, dass jemand versucht, dich dazu zu bewegen, ihm Zugriff auf deine Daten zu gewähren. Fahre in diesem Fall nicht fort, sondern wende dich an deine Administration.",
+    "Alternative log in using app password" : "Alternative Anmeldung mittels App-Passwort",
+    "Account connected" : "Konto verbunden",
+    "Your client should now be connected!" : "Dein Client sollte nun verbunden sein!",
+    "You can close this window." : "Du kannst dieses Fenster schließen.",
+    "Account access" : "Kontozugriff ",
     "More actions" : "Weitere Aktionen",
     "User menu" : "Benutzermenü",
     "Your guest name: {user}" : "Dein Gastname: {user}",
@@ -336,7 +358,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Informationen zur ordnungsgemäßen Konfiguration des Servers sind {linkStart}in der Dokumentation zu finden{linkEnd}",
     "Autoconfig file detected" : "Autoconfig-Datei erkannt",
     "The setup form below is pre-filled with the values from the config file." : "Das folgende Einrichtungsformular ist mit den Werten aus der Konfigurationsdatei vorausgefüllt.",
-    "Security warning" : "Sicherheitswarnung",
     "Create administration account" : "Administrationskonto erstellen",
     "Administration account name" : "Name des Administrationskontos",
     "Administration account password" : "Passwort des Administrationskontos",
@@ -389,6 +410,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} ausgewählt)",
     "Error loading file exists template" : "Fehler beim Laden der vorhanden Dateivorlage",
     "Saving …" : "Speichere …",
+    "Groups" : "Gruppen",
+    "Group list is empty" : "Gruppenliste ist leer",
+    "Unable to retrieve the group list" : "Gruppenliste konnte nicht abgerufen werden",
     "seconds ago" : "Gerade eben",
     "Connection to server lost" : "Verbindung zum Server verloren",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem beim Laden der Seite, Seite wird in %n Sekunde nochmals geladen","Problem beim Laden der Seite, Seite wird in %n Sekunden erneut geladen"],
@@ -439,21 +463,9 @@ OC.L10N.register(
     "Skip to navigation of app" : "Zum Navigationsbereich der App springen",
     "Go to %s" : "%s aufrufen",
     "Get your own free account" : "Hole dir dein eigenes kostenloses Konto",
-    "Connect to your account" : "Verbinde dich mit deinem Konto",
-    "Please log in before granting %1$s access to your %2$s account." : "Bitte melde dich an, bevor du %1$s Zugriff auf dein %2$s-Konto gewährst.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Solltest du aktuell nicht versuchen, ein neues Gerät oder eine neue App einzurichten, dann kann es sein, dass jemand versucht, dich dazu zu bewegen, ihm Zugriff auf deine Daten zu gewähren. Fahre in diesem Fall nicht fort, sondern wende dich an deine Administration.",
-    "App password" : "App-Passwort",
-    "Grant access" : "Zugriff gewähren",
-    "Alternative log in using app password" : "Alternative Anmeldung mittels App-Passwort",
-    "Account access" : "Kontozugriff ",
-    "Currently logged in as %1$s (%2$s)." : "Aktuell angemeldet als %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Du bist dabei, %1$s Zugriff auf dein %2$s-Konto zu gewähren.",
-    "Account connected" : "Konto verbunden",
-    "Your client should now be connected!" : "Dein Client sollte nun verbunden sein!",
-    "You can close this window." : "Du kannst dieses Fenster schließen.",
     "Previous" : "Vorige",
     "This share is password-protected" : "Diese Freigabe ist passwortgeschützt",
-    "The password is wrong or expired. Please try again or request a new one." : "Das Passwort ist falsch oder abgelaufen. Bitte versuche es erneut oder forder ein neues Passwort an.",
+    "The password is wrong or expired. Please try again or request a new one." : "Das Passwort ist falsch oder abgelaufen. Bitte erneut versuchen oder ein neues Passwort anfordern.",
     "Please type in your email address to request a temporary password" : "Bitte gib deine E-Mail-Adresse ein, um ein vorläufiges Passwort anzufordern",
     "Email address" : "E-Mail-Adresse",
     "Password sent!" : "Passwort wurde verschickt",
@@ -503,6 +515,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert",
     "Searching …" : "Suche …",
     "Logging in …" : "Melde an…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Es wurden mehrere ungültige Anmeldeversuche von deiner IP-Adresse festgestellt. Daher wird die nächste Anmeldung um 30 Sekunden verzögert.",
     "Loading apps …" : "Lade Apps …",
     "Installing apps …" : "Installiere Apps …",
     "Loading your contacts …" : "Lade deine Kontakte …",
@@ -520,7 +533,6 @@ OC.L10N.register(
     "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
     "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
     "Restricted" : "Eingeschränkt",
-    "Invisible" : "Unsichtbar",
     "Delete" : "Löschen",
     "Rename" : "Umbenennen",
     "Collaborative tags" : "Kollaborative Schlagworte",
@@ -535,6 +547,9 @@ OC.L10N.register(
     "Configure the database" : "Datenbank einrichten",
     "Only %s is available." : "Es ist nur %s verfügbar.",
     "Database account" : "Datenbankkonto",
-    "Installing …" : "Installiere …"
+    "Installing …" : "Installiere …",
+    "Please log in before granting %1$s access to your %2$s account." : "Bitte melde dich an, bevor du %1$s Zugriff auf dein %2$s-Konto gewährst.",
+    "Currently logged in as %1$s (%2$s)." : "Aktuell angemeldet als %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Du bist dabei, %1$s Zugriff auf dein %2$s-Konto zu gewähren."
 },
 "nplurals=2; plural=(n != 1);");
