@@ -42,6 +42,7 @@ OC.L10N.register(
     "Not found" : "Ez da aurkitu",
     "Node is locked" : "Nodoa blokeatuta dago",
     "Bad request" : "Eskaera txarra",
+    "Input text is too long" : "Sarrera testua luzeegia da",
     "Requested task type does not exist" : "Eskatutako eginkizun mota ez da existitzen",
     "Necessary language model provider is not available" : "Beharrezko lengoaia-modelo hornitzailea ez dago eskuragarri",
     "No text to image provider is available" : "Ez dago testutik irudirako hornitzailerik erabilgarri",
@@ -49,6 +50,7 @@ OC.L10N.register(
     "No translation provider available" : "Ez dago itzulpen-hornitzailerik erabilgarri",
     "Could not detect language" : "Ezin izan da hizkuntza hauteman",
     "Unable to translate" : "Ezin izan da itzuli",
+    "No valid filters provided" : "Ez da baliozko iragazkirik eman",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Konponketa pausoa:",
     "Repair info:" : "Konponketa informazioa:",
@@ -204,12 +206,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Eguneraketak huts egin du. Mesedez, jakinarazi arazoa <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud komunitateari</a>.",
     "Continue to {productName}" : "Jarraitu hona: {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Eguneraketa behar bezala egin da. {productName} ra birbideratuko zaitugu %nsegundotan.","Eguneraketa behar bezala egin da. {productName} (e)ra birbideratuko zaitugu %n segundotan."],
+    "Done" : "Egina",
     "Applications menu" : "Aplikazio-menua",
     "Apps" : "Aplikazioak",
     "More apps" : "Aplikazio gehiago",
     "_{count} notification_::_{count} notifications_" : ["Jakinarazpen {count}","{count} jakinarazpenak"],
     "No" : "Ez",
     "Yes" : "Bai",
+    "App password" : "Aplikazioaren pasahitza",
+    "Grant access" : "Baimendu sarrera",
     "The remote URL must include the user." : "Urruneko URLak erabiltzailea eduki behar du.",
     "Invalid remote URL." : "Urruneko URL baliogabea",
     "Failed to add the public link to your Nextcloud" : "Huts egin du esteka publikoa zure Nextcloudera gehitzean",
@@ -225,13 +230,16 @@ OC.L10N.register(
     "Search in current app" : "Bilatu aplikazio honetan",
     "Clear search" : "Garbitu bilaketa",
     "Search everywhere" : "Bilatu nonahi",
+    "Searching …" : "Bilatzen …",
     "Start typing to search" : "Hasi idazten bilatzeko",
+    "Minimum search length is {minSearchLength} characters" : "Gutxieneko bilaketa-luzera {minSearchLength} karakterekoa da",
     "No matching results" : "Ez dago bilaketaren emaitzarik",
     "Today" : "Gaur",
     "Last 7 days" : "Azken 7 egunetan",
     "Last 30 days" : "Azken 30 egunetan",
     "This year" : "Urte honetan",
     "Last year" : "Azken urtea",
+    "Between {startDate} and {endDate}" : "{startDate} eta {endDate} bitartean",
     "Unified search" : "Bilaketa bateratua",
     "Search apps, files, tags, messages" : "Bilatu aplikazioak, fitxategiak, etiketak, mezuak",
     "Places" : "Lekuak",
@@ -243,11 +251,13 @@ OC.L10N.register(
     "Results" : "Emaitzak",
     "Load more results" : "Kargatu emaitza gehiago ",
     "Search in" : "Bilatu hemen",
+    "Partial matches" : "Bat etortze partzialak",
     "Log in" : "Hasi saioa",
+    "Logging in …" : "Saioa hasten …",
     "Log in to {productName}" : "Hasi saioa {productName}-(e)n",
     "Wrong login or password." : "Erabiltzaile edo pasahitz okerra.",
     "This account is disabled" : "Kontu hau desgaituta dago",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Saioa hasteko hainbat saiakera baliogabe jaso ditugu zure IPtik. Ondorioz, zure hurrengo saio hasiera 30 segundo atzeratuko da.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Saioa hasteko saiakera oker gehiegi. Mesedez, saiatu berriro 30 segundo barru.",
     "Account name or email" : "Kontu izena edo posta elektronikoa",
     "Account name" : "Kontuaren izena",
     "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
@@ -257,6 +267,7 @@ OC.L10N.register(
     "An internal error occurred." : "Barne-errore bat gertatu da.",
     "Please try again or contact your administrator." : "Saiatu berriro edo jarri harremanetan zure administratzailearekin.",
     "Password" : "Pasahitza",
+    "Remember me" : "Gogoratu nirekin",
     "Log in with a device" : "Hasi saioa gailu batekin",
     "Login or email" : "Erabiltzaile-izen edo e-posta",
     "Your account is not setup for passwordless login." : "Zure kontua ez dago pasahitzik gabeko autentifikaziorako konfiguratua.",
@@ -280,11 +291,13 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumentu, kalkulu-orri eta aurkezpen kolaboratiboak, Collabora Online-en sortuak.",
     "Distraction free note taking app." : "Distrakziorik gabeko oharrak hartzeko aplikazioa.",
     "Recommended apps" : "Gomendatutako aplikazioak",
+    "Loading apps …" : "Aplikazioak kargatzen …",
     "Could not fetch list of apps from the App Store." : "Ezin izan da aplikazioen zerrenda eskuratu aplikazioen dendatik.",
     "App download or installation failed" : "Huts egin du aplikazioaren deskarga edo instalazioak",
     "Cannot install this app because it is not compatible" : "Ezin da aplikazio hau instalatu ez delako bateragarria",
     "Cannot install this app" : "Ezin da aplikazio hau instalatu",
     "Skip" : "Saltatu",
+    "Installing apps …" : "Aplikazioak instalatzen …",
     "Install recommended apps" : "Instalatu gomendatutako aplikazioak",
     "Online" : "Linean",
     "Away" : "Kanpoan",
@@ -292,10 +305,14 @@ OC.L10N.register(
     "Do not disturb" : "Ez molestatu",
     "Mute all notifications" : "Isilarazi jakinarazpen guztiak",
     "Invisible" : "Ikusezina",
+    "Appear offline" : "Lineaz kanpo agertzen da",
     "Avatar of {displayName}" : "{displayName}-(r)en avatarra",
     "Settings menu" : "Ezarpenen menua",
+    "Loading your contacts …" : "Zure kontaktuak kargatzen …",
+    "Looking for {term} …" : "{term} bilatzen …",
     "Search contacts" : "Bilatu kontaktuak",
     "Reset search" : "Berrezarri bilaketa",
+    "Search contacts …" : "Kontaktuak bilatzen …",
     "Could not load your contacts" : "Ezin izan dira zure kontaktuak kargatu",
     "No contacts found" : "Ez da kontakturik aurkitu",
     "Show all contacts" : "Erakutsi kontaktu guztiak",
@@ -307,11 +324,20 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Errorea gertatu da {type} bilatzean",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Bilaketa idazten hasten zarenean hasten da eta emaitzak gezi-teklen bidez lor daitezke",
     "Search for {name} only" : "Biatu {name} bakarrik",
+    "Loading more results …" : "Emaitza gehiago kargatzen …",
     "Forgot password?" : "Pasahitza ahaztu duzu?",
     "Back to login form" : "Itzuli saio hasierara",
     "Back" : "Atzera",
     "Login form is disabled." : "Saioa hasteko inprimakia desgaituta dago.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud saioa hasteko inprimakia desgaituta dago. Erabili saioa hasteko beste aukera eskuragarri badago edo jarri harremanetan zure administrazioarekin.",
+    "Connect to your account" : "Konektatu zure kontura",
+    "Security warning" : "Segurtasun abisua",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Gailu edo aplikazio berri bat konfiguratzen saiatzen ari ez bazara, norbait zu engainatzen saiatzen ari da zure datuetarako sarbidea eman diezaiozun. Kasu horretan, jarraitu ordez jarri harremanetan sistemaren administratzailearekin.",
+    "Alternative log in using app password" : "Saio hasiera alternatiboa aplikazioaren pasahitza erabiliz",
+    "Account connected" : "Kontua konektatuta",
+    "Your client should now be connected!" : "Zure bezeroak konektatua behar luke orain!",
+    "You can close this window." : "Leiho hau itxi dezakezu.",
+    "Account access" : "Kontuaren sarbidea",
     "More actions" : "Ekintza gehiago",
     "User menu" : "Erabiltzailearen menua",
     "Your guest name: {user}" : "Zure gonbidatu izena: {user}",
@@ -329,13 +355,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Jakiteko zure zerbitzaria nola konfiguratu zuzen, {linkStart}begiratu dokumentazioa{linkEnd}",
     "Autoconfig file detected" : "Autoconfig fitxategia atzeman da",
     "The setup form below is pre-filled with the values from the config file." : "Beheko konfigurazio formularioa konfigurazio fitxategiko balioekin aurrez betetzen da.",
-    "Security warning" : "Segurtasun abisua",
     "Create administration account" : "Sortu administrazio kontua",
     "Administration account name" : "Administrazio kontuaren izena",
     "Administration account password" : "Administrazio kontuaren pasahitza",
     "Storage & database" : "Biltegia eta datu-basea",
     "Data folder" : "Datuen karpeta",
     "Database configuration" : "Datu-basearen ezarpenak",
+    "Database type" : "Datu-base mota",
     "Only {firstAndOnlyDatabase} is available." : "Soilik {firstAndOnlyDatabase} dago eskuragarri",
     "Install and activate additional PHP modules to choose other database types." : "Instalatu eta aktibatu PHP modulu osagarriak, beste datu-base mota batzuk aukeratzeko.",
     "For more details check out the documentation." : "Xehetasun gehiago nahi izanez gero, begiratu dokumentazioa.",
@@ -343,6 +369,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "SQLite hautatu duzu datu-base gisa.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite garapenerako eta instantzia txikietarako soilik erabili behar litzateke. Produkziorako beste datu-base sistema bat erabiltzea gomendatzen dugu.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Fitxategiak sinkronizatzeko bezeroak erabiltzen badituzu, SQLite ez da batere gomendagarria.",
+    "Database connection" : "Datu-basearen konexioa",
     "Database user" : "Datu-basearen erabiltzailea",
     "Database password" : "Datu-basearen pasahitza",
     "Database name" : "Datu-basearen izena",
@@ -350,6 +377,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zehaztu ataka, makinaren izenarekin batera (adb. localhost:5432).",
     "Database host" : "Datu-basearen ostalaria",
     "localhost" : "localhost",
+    "Installing …" : "Instalatzen …",
     "Install" : "Instalatu",
     "Need help?" : "Laguntza behar duzu?",
     "See the documentation" : "Ikusi dokumentazioa",
@@ -358,6 +386,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Zure nabigatzailea ez da onartzen. Mesedez, eguneratu bertsio berriago batera edo onartzen den batera.",
     "Continue with this unsupported browser" : "Jarraitu onartzen ez den arakatzaile honekin",
     "Supported versions" : "Onartutako bertsioak",
+    "Search {types} …" : "Bilatu {types} …",
     "Choose {file}" : "Aukeratu {file}",
     "Choose" : "Aukeratu",
     "Copy to {target}" : "Kopiatu hona: {target}",
@@ -378,6 +407,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} hautatuta)",
     "Error loading file exists template" : "Errorea fitxategia existitzen da txantiloia kargatzean",
     "Saving …" : "Gordetzen  ...",
+    "Groups" : "Taldeak",
+    "Group list is empty" : "Talde zerrenda hutsik dago",
+    "Unable to retrieve the group list" : "Ezin izan da talde zerrenda eskuratu",
     "seconds ago" : "segundo lehenago",
     "Connection to server lost" : "Zerbitzariarekiko konexioa eten da",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Arazoa orria kargatzerakoan, segundo %n barru berriz kargatuko da","Arazoa orria kargatzerakoan,  %n segundo barru berriz kargatuko da"],
@@ -428,18 +460,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Salto aplikazioaren nabigaziora",
     "Go to %s" : "Joan %s-ra",
     "Get your own free account" : "Eskuratu zure kontu propioa doan",
-    "Connect to your account" : "Konektatu zure kontura",
-    "Please log in before granting %1$s access to your %2$s account." : "Hasi saioa %1$s-(r)i  zure %2$s kontura sarbidea eman aurretik.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Gailu edo aplikazio berri bat konfiguratzen saiatzen ari ez bazara, norbait zu engainatzen saiatzen ari da zure datuetarako sarbidea eman diezaiozun. Kasu horretan, jarraitu ordez jarri harremanetan sistemaren administratzailearekin.",
-    "App password" : "Aplikazioaren pasahitza",
-    "Grant access" : "Baimendu sarrera",
-    "Alternative log in using app password" : "Saio hasiera alternatiboa aplikazioaren pasahitza erabiliz",
-    "Account access" : "Kontuaren sarbidea",
-    "Currently logged in as %1$s (%2$s)." : "Une honetan %1$s (%2$s) gisa hasita dago saioa.",
-    "You are about to grant %1$s access to your %2$s account." : "%1$s-(r)i  zure %2$s kontura sarbidea ematear zaude.",
-    "Account connected" : "Kontua konektatuta",
-    "Your client should now be connected!" : "Zure bezeroak konektatua behar luke orain!",
-    "You can close this window." : "Leiho hau itxi dezakezu.",
     "Previous" : "Aurrekoa",
     "This share is password-protected" : "Partekatze hau pasahitzez babestua dago.",
     "The password is wrong or expired. Please try again or request a new one." : "Pasahitza oker dago edo iraungita dago. Mesedez, saiatu berriro edo eskatu berri bat.",
@@ -492,6 +512,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Esteka zuzena arbelera kopiatuta",
     "Searching …" : "Bilatzen…",
     "Logging in …" : "Saioa hasten...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Saioa hasteko hainbat saiakera baliogabe jaso ditugu zure IPtik. Ondorioz, zure hurrengo saio hasiera 30 segundo atzeratuko da.",
     "Loading apps …" : "Aplikazioak kargatzen...",
     "Installing apps …" : "Aplikazioak instalatzen...",
     "Loading your contacts …" : "Zure kontaktuak kargatzen...",
@@ -523,6 +544,9 @@ OC.L10N.register(
     "Configure the database" : "Konfiguratu datu-basea",
     "Only %s is available." : "Soilik %s dago eskuragarri.",
     "Database account" : "Datu-basearen kontua",
-    "Installing …" : "Instalatzen ..."
+    "Installing …" : "Instalatzen ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Hasi saioa %1$s-(r)i  zure %2$s kontura sarbidea eman aurretik.",
+    "Currently logged in as %1$s (%2$s)." : "Une honetan %1$s (%2$s) gisa hasita dago saioa.",
+    "You are about to grant %1$s access to your %2$s account." : "%1$s-(r)i  zure %2$s kontura sarbidea ematear zaude."
 },
 "nplurals=2; plural=(n != 1);");
