@@ -206,12 +206,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mise à jour a échoué. Veuillez reporter le problème à la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">communauté Nextcloud</a>.",
     "Continue to {productName}" : "Continuer vers {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes."],
+    "Done" : "Terminé",
     "Applications menu" : "Menu des applications",
     "Apps" : "Applications",
     "More apps" : "Plus d’applications",
     "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications","{count} notifications"],
     "No" : "Non",
     "Yes" : "Oui",
+    "App password" : "Mot de passe d'application",
+    "Grant access" : "Autoriser l'accès",
     "The remote URL must include the user." : "L'URL distante doit inclure l'utilisateur.",
     "Invalid remote URL." : "URL distante invalide.",
     "Failed to add the public link to your Nextcloud" : "Impossible d'ajouter le lien public à votre Nextcloud",
@@ -253,7 +256,7 @@ OC.L10N.register(
     "Log in to {productName}" : "Se connecter à {productName}",
     "Wrong login or password." : "Mauvais identifiant ou mot de passe.",
     "This account is disabled" : "Ce compte est désactivé",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Nous avons détecté plusieurs tentatives de connexion invalides depuis votre adresse IP. C’est pourquoi votre prochaine connexion sera retardée de 30 secondes.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Trop de tentatives de connexion infructueuses. Merci de réessayer dans 30 secondes.",
     "Account name or email" : "Nom d’utilisateur ou adresse e-mail",
     "Account name" : "Nom du compte",
     "Server side authentication failed!" : "L’authentification sur le serveur a échoué !",
@@ -326,6 +329,14 @@ OC.L10N.register(
     "Back" : "Retour",
     "Login form is disabled." : "Le formulaire de connexion est désactivé.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Le formulaire de connexion Nextcloud est désactivé. Utilisez une autre option de connexion si disponible ou contactez un administrateur.",
+    "Connect to your account" : "Connectez-vous à votre compte",
+    "Security warning" : "Avertissement de sécurité",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si vous n'essayez pas d'ajouter un nouveau périphérique ou une nouvelle application, quelqu'un fait une tentative d'accès à vos données. Dans ce cas, ne continuez pas et contactez votre administrateur système.",
+    "Alternative log in using app password" : "Connexion à l'aide d'un mot de passe d'application",
+    "Account connected" : "Compte connecté",
+    "Your client should now be connected!" : "Votre client devrait maintenant être connecté !",
+    "You can close this window." : "Vous pouvez fermer cette fenêtre.",
+    "Account access" : "Accès au compte",
     "More actions" : "Plus d'actions",
     "User menu" : "Menu utilisateur",
     "Your guest name: {user}" : "Votre nom d'invité : {user}",
@@ -343,7 +354,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Pour savoir comment configurer correctement votre serveur, veuillez lire la {linkStart}documentation{linkEnd}.",
     "Autoconfig file detected" : "Fichier de configuration automatique détecté",
     "The setup form below is pre-filled with the values from the config file." : "Le formulaire de configuration ci-dessous est pré-rempli avec les valeurs du fichier de configuration.",
-    "Security warning" : "Avertissement de sécurité",
     "Create administration account" : "Créer un compte administrateur",
     "Administration account name" : "Nom du compte administrateur",
     "Administration account password" : "Mot de passe du compte administrateur",
@@ -396,6 +406,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} sélectionné(s))",
     "Error loading file exists template" : "Erreur lors du chargement du modèle de fichier existant",
     "Saving …" : "Enregistrement…",
+    "Groups" : "Groupes",
+    "Group list is empty" : "La liste des groupes est vide",
+    "Unable to retrieve the group list" : "Impossible de récupérer la liste des groupes",
     "seconds ago" : "Il y a quelques secondes",
     "Connection to server lost" : "La connexion au serveur a été perdue",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problème de chargement de la page, actualisation dans %n seconde","Problème de chargement de la page, actualisation dans %n secondes","Problème de chargement de la page, actualisation dans %n secondes"],
@@ -446,18 +459,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Passer à la navigation d'application",
     "Go to %s" : "Aller à %s",
     "Get your own free account" : "Obtenez votre compte personnel gratuit",
-    "Connect to your account" : "Connectez-vous à votre compte",
-    "Please log in before granting %1$s access to your %2$s account." : "Veuillez vous connecter avant d'autoriser %1$s à accéder à votre compte %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si vous n'essayez pas d'ajouter un nouveau périphérique ou une nouvelle application, quelqu'un fait une tentative d'accès à vos données. Dans ce cas, ne continuez pas et contactez votre administrateur système.",
-    "App password" : "Mot de passe d'application",
-    "Grant access" : "Autoriser l'accès",
-    "Alternative log in using app password" : "Connexion à l'aide d'un mot de passe d'application",
-    "Account access" : "Accès au compte",
-    "Currently logged in as %1$s (%2$s)." : "Connecté en tant que %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Vous êtes sur le point d’accorder à « %1$s » l’accès à votre compte « %2$s ».",
-    "Account connected" : "Compte connecté",
-    "Your client should now be connected!" : "Votre client devrait maintenant être connecté !",
-    "You can close this window." : "Vous pouvez fermer cette fenêtre.",
     "Previous" : "Précédent",
     "This share is password-protected" : "Ce partage est protégé par mot de passe",
     "The password is wrong or expired. Please try again or request a new one." : "Le mot de passe est incorrect ou expiré. Ré-essayez ou demandez-en un nouveau.",
@@ -510,6 +511,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Lien direct copié dans le presse-papiers",
     "Searching …" : "Recherche…",
     "Logging in …" : "Connexion…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Nous avons détecté plusieurs tentatives de connexion invalides depuis votre adresse IP. C’est pourquoi votre prochaine connexion sera retardée de 30 secondes.",
     "Loading apps …" : "Chargement des applis…",
     "Installing apps …" : "Installation des applis en cours...",
     "Loading your contacts …" : "Chargement de vos contacts...",
@@ -541,6 +543,9 @@ OC.L10N.register(
     "Configure the database" : "Configurer la base de données",
     "Only %s is available." : "Seul(e) %s est disponible.",
     "Database account" : "Compte de base de données",
-    "Installing …" : "Installation..."
+    "Installing …" : "Installation...",
+    "Please log in before granting %1$s access to your %2$s account." : "Veuillez vous connecter avant d'autoriser %1$s à accéder à votre compte %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Connecté en tant que %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Vous êtes sur le point d’accorder à « %1$s » l’accès à votre compte « %2$s »."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
