@@ -16,28 +16,41 @@ OC.L10N.register(
     "Invalid file provided" : "Дадена е невалидна датотека",
     "No image or file provided" : "Не е доставена фотографија или датотека",
     "Unknown filetype" : "Непознат тип на датотека",
-    "An error occurred. Please contact your admin." : "Настана грешка. Контактирате со администраторот.",
+    "An error occurred. Please contact your admin." : "Настана грешка. Контактирајте со администраторот.",
     "Invalid image" : "Невалидна фотографија",
     "State token does not match" : "Токенот не се совпаѓа",
     "Invalid app password" : "Погрешна лозинка за апликација",
     "Could not complete login" : "Неможе да се комплетира најавувањето",
+    "State token missing" : "Недостасува безбедносен токен",
     "Your login token is invalid or has expired" : "Вашиот токен за најава е невалиден или истечен",
+    "Please use original client" : "Ве молиме користете оргинален клиент",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Оваа верзија повеќе не е поддржана и Push известувањата се ограничени.",
     "Login" : "Најава",
+    "Unsupported email length (>255)" : "Неподдржана должина на е-пошта адреса (>255)",
     "Password reset is disabled" : "Ресетирање на лозинката е оневозможено",
     "Could not reset password because the token is expired" : "Неможе да се промени лозинката бидејќи токенот е истечен",
     "Could not reset password because the token is invalid" : "Неможе да се промени лозинката бидејќи токенот е невалиден",
+    "Password is too long. Maximum allowed length is 469 characters." : "Лозинката е премногу долга. Максимална дозволена должина е 469 карактери.",
     "%s password reset" : "%s ресетирање на лозинката",
     "Password reset" : "Ресетирај лозинка",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете на следното копче за да ја ресетирате вашата лозинка. Доколку не сте побарале ресетирање на лозинка, игнорирајте ја оваа порака.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете на следниот линк за да ја ресетирате вашата лозинка. Доколку не сте побарале ресетирање на лозинка, игнорирајте ја оваа порака.",
     "Reset your password" : "Ресетирај ја твојата лозинка",
+    "The given provider is not available" : "Провајдерот не е достапен",
     "Task not found" : "Задачата не е пронајдена",
     "Internal error" : "Внатрешна грешка",
     "Not found" : "Не е пронајдено",
+    "Node is locked" : "Нодот е заклучен",
+    "Bad request" : "Неправилно барање",
+    "Input text is too long" : "Влезниот текст е премногу долг",
+    "Requested task type does not exist" : "Бараниот тип на задача не постои",
+    "Necessary language model provider is not available" : "Не е достапен потребниот давател на јазичен модел",
+    "No text to image provider is available" : "Не е достапен давател на услуги за текст во слика",
     "Image not found" : "Сликата не е пронајдена",
+    "No translation provider available" : "Нема достапен давател на услуги за превод",
     "Could not detect language" : "Неможе да се детектира јазикот",
     "Unable to translate" : "Неможе да се преведе",
+    "No valid filters provided" : "Не се обезбедени валидни филтри",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Чекори за поправка:",
     "Repair info:" : "Инфо при поправка:",
@@ -46,8 +59,11 @@ OC.L10N.register(
     "Nextcloud Server" : "Nextcloud Сервер",
     "Some of your link shares have been removed" : "Некој од вашите линкови што ги споделивте се избришани",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради безбедносен ризик некој од вашите споделувања се избришани. Ве молиме видете го линкот за повеќе информации.",
+    "The account limit of this instance is reached." : "Лимитот на сметки за оваа инстанца е достигнат.",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Внеси го твојот клуч за претплата во апликацијата за поддршка за да го зголемиш лимитот на сметката. Ова исто така ти ги овозможува сите дополнителни бенефиции што ги нуди Nextcloud Enterprise и е силно препорачано за користење во компании.",
     "Learn more ↗" : "Научи повеќе ↗",
     "Preparing update" : "Ја подготвувам надградбата",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Ве молиме користете ја командната линија за ажурирање бидејќи ажурирање преку прелистувач е оневозможено во config.php.",
     "Turned on maintenance mode" : "Вклучен е модот за одржување",
     "Turned off maintenance mode" : "Ислкучен е модот за одржување",
     "Maintenance mode is kept active" : "Модот за одржување е уште активен",
@@ -63,15 +79,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (некомпатибилен)",
     "The following apps have been disabled: %s" : "Следниве апликации се оневозможени: %s",
     "Already up to date" : "Веќе ажурирано",
+    "Windows Command Script" : "Windows Command скрипта",
+    "Electronic book document" : "Електронски документ со книга",
+    "TrueType Font Collection" : "Колекција на TrueType фонтови",
+    "Web Open Font Format" : "Веб формат на отворен фонт",
+    "GPX geographic data" : "GPX geographic data",
+    "Gzip archive" : "Gzip архива",
+    "Adobe Illustrator document" : "Adobe Illustrator документ",
+    "Java source code" : "Java код",
+    "JavaScript source code" : "JavaScript код",
+    "JSON document" : "JSON документ",
+    "Microsoft Access database" : "Microsoft Access база",
+    "Microsoft OneNote document" : "Microsoft OneNote документ",
+    "Microsoft Word document" : "Microsoft Word документ",
     "Unknown" : "Непознат",
-    "unknown text" : "непознат текст",
-    "Hello world!" : "Здраво свету!",
-    "sunny" : "сончево",
-    "Hello {name}, the weather is {weather}" : "Здраво {name}, времето е {weather}",
-    "Hello {name}" : "Здраво {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ова се вашите резултати од пребарувањето<script>alert(1)</script></strong>",
-    "new" : "ново",
-    "_download %n file_::_download %n files_" : ["преземи %n датотека","преземи %n датотеки"],
+    "PDF document" : "PDF документ",
+    "PostScript document" : "PostScript документ",
+    "RSS summary" : "RSS резиме",
+    "Android package" : "Андроид пакет",
+    "KML geographic data" : "KML geographic data",
+    "KML geographic compressed data" : "KML geographic compressed data",
+    "Lotus Word Pro document" : "Lotus Word Pro документ",
+    "Excel spreadsheet" : "Excel табела",
+    "Excel add-in" : "Excel додаток",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 бинарна табела",
+    "Excel spreadsheet template" : "Excel табела шаблон",
+    "Outlook Message" : "Outlook порака",
+    "PowerPoint presentation" : "PowerPoint презентација",
+    "PowerPoint add-in" : "PowerPoint додаток",
+    "PowerPoint presentation template" : "PowerPoint презентација шаблон",
+    "Word document" : "Word документ",
+    "ODF formula" : "ODF формула",
+    "ODG drawing" : "ODG цртеж",
+    "ODG drawing (Flat XML)" : "ODG цртеж (Flat XML)",
+    "ODG template" : "ODG шаблон",
+    "ODP presentation" : "ODP презентација",
+    "ODP presentation (Flat XML)" : "ODP презентација (Flat XML)",
+    "ODP template" : "ODP шаблон",
+    "ODS spreadsheet" : "ODS табела",
+    "ODS spreadsheet (Flat XML)" : "ODS табел (Flat XML)",
+    "ODS template" : "ODS шаблон",
+    "ODT document" : "ODT документ",
+    "ODT document (Flat XML)" : "ODT документ (Flat XML)",
+    "ODT template" : "ODT шаблон",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 презентација",
+    "PowerPoint 2007 show" : "PowerPoint 2007 презентација",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 презентација шаблон",
+    "Excel 2007 spreadsheet" : "Excel 2007 табела",
+    "Excel 2007 spreadsheet template" : "Excel 2007 spreadsheet template",
+    "Word 2007 document" : "Word 2007 документ",
+    "Word 2007 document template" : "Word 2007 документ шаблон",
+    "Microsoft Visio document" : "Microsoft Visio документ",
+    "WordPerfect document" : "WordPerfect документ",
+    "7-zip archive" : "7-zip архива",
+    "Blender scene" : "Blender сцена",
+    "Bzip2 archive" : "Bzip2 архива",
+    "Debian package" : "Debian пакет",
+    "FictionBook document" : "FictionBook документ",
+    "Unknown font" : "Непознат фонт",
+    "Krita document" : "Krita документ",
+    "Mobipocket e-book" : "Mobipocket е-книга",
+    "Windows Installer package" : "Windows инсталациски пакет",
+    "Perl script" : "Perl сктипта",
+    "PHP script" : "PHP скрипта",
+    "Tar archive" : "Tar архива",
+    "XML document" : "XML документ",
+    "YAML document" : "YAML документ",
+    "Zip archive" : "Zip архива",
+    "Zstandard archive" : "Zstandard архива",
+    "AAC audio" : "AAC аудио",
+    "FLAC audio" : "FLAC аудио",
+    "MPEG-4 audio" : "MPEG-4 аудио",
+    "MP3 audio" : "MP3 аудио",
+    "Ogg audio" : "Ogg аудио",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe стандард аудио",
+    "WebM audio" : "WebM аудио",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast плејлиста",
+    "Windows BMP image" : "Windows BMP слика",
+    "Better Portable Graphics image" : "Better Portable Graphics слика",
+    "EMF image" : "EMF слика",
+    "GIF image" : "GIF слика",
+    "HEIC image" : "HEIC слика",
+    "HEIF image" : "HEIF слика",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 слика",
+    "JPEG image" : "JPEG слика",
+    "PNG image" : "PNG слика",
+    "SVG image" : "SVG слика",
+    "Truevision Targa image" : "Truevision Targa слика",
+    "TIFF image" : "TIFF слика",
+    "WebP image" : "WebP слика",
+    "Digital raw image" : "Raw слика",
+    "Windows Icon" : "Windows икона",
+    "Email message" : "Е-пошта порака",
+    "VCS/ICS calendar" : "VCS/ICS календар",
+    "CSS stylesheet" : "CSS stylesheet",
+    "CSV document" : "CSV документ",
+    "HTML document" : "HTML документ",
+    "Markdown document" : "Markdown документ",
+    "Org-mode file" : "Org-mode датотека",
+    "Plain text document" : "Plain текст документ",
+    "Rich Text document" : "Rich текст документ",
+    "Electronic business card" : "Електронска бизнис картичка",
+    "C++ source code" : "C++ код",
+    "LDIF address book" : "LDIF адресар",
+    "NFO document" : "NFO документ",
+    "PHP source" : "PHP извор",
+    "Python script" : "Python скрипта",
+    "ReStructuredText document" : "ReStructuredText документ",
+    "3GPP multimedia file" : "3GPP мултимедиална датотека",
+    "MPEG video" : "MPEG видео",
+    "DV video" : "DV видео",
+    "MPEG-2 transport stream" : "MPEG-2 transport stream",
+    "MPEG-4 video" : "MPEG-4 видео",
+    "Ogg video" : "Ogg видео",
+    "QuickTime video" : "QuickTime видео",
+    "WebM video" : "WebM видео",
+    "Flash video" : "Flash видео",
+    "Matroska video" : "Matroska видео",
+    "Windows Media video" : "Windows Media видео",
+    "AVI video" : "AVI видео",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Во тек е надградба на системот, доколку ја напуштите оваа страница може да дојде до прекин на некој процес во некој дел.",
     "Update to {version}" : "Надгради на {version}",
     "An error occurred." : "Се случи грешка",
@@ -80,45 +206,68 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Надградбата не беше успешна. Ве молиме овој проблем да го пријавите во <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">заедницата</a>.",
     "Continue to {productName}" : "Продолжи кон {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирањето беше успешно. Пренасочување кон {productName} за %n секунда.","Ажурирањето беше успешно. Пренасочување кон {productName} за %n секунди."],
+    "Done" : "Готово",
+    "Applications menu" : "Мени со апликации",
     "Apps" : "Аппликации",
     "More apps" : "Повеќе апликации",
-    "_{count} notification_::_{count} notifications_" : ["Едно исзестување","{count} известувања"],
+    "_{count} notification_::_{count} notifications_" : ["{count} известување","{count} известувања"],
     "No" : "Не",
     "Yes" : "Да",
+    "App password" : "Лозинка за апликација",
+    "Grant access" : "Дозволи пристап",
+    "The remote URL must include the user." : "URL-то мора да содржи корисник.",
+    "Invalid remote URL." : "Неправилна URL.",
     "Failed to add the public link to your Nextcloud" : "Неуспешно додавање на јавниот линк",
+    "Federated user" : "Федерален корисник",
+    "user@your-nextcloud.org" : "korisnik@cloud-domain.org",
     "Create share" : "Ново споделување",
+    "Direct link copied" : "Копирана директна врска",
+    "Please copy the link manually:" : "Копирајте го линкот рачно:",
+    "Custom date range" : "Прилагоден временски опсег",
     "Pick start date" : "Избери почетен датум",
     "Pick end date" : "Избери краен датум",
+    "Search in date range" : "Пребарај во временски опсег",
+    "Search in current app" : "Пребарај во тековната апликација",
+    "Clear search" : "Исчисти пребарување",
     "Search everywhere" : "Барај насекаде",
-    "Searching …" : "Пребарување ...",
+    "Searching …" : "Пребарување …",
     "Start typing to search" : "Напишете нешто за пребарување",
+    "Minimum search length is {minSearchLength} characters" : "Минимална должина за пребарување е {minSearchLength} карактери",
     "No matching results" : "Нема соодветни резултати",
     "Today" : "Денес",
     "Last 7 days" : "Предходни 7 дена",
     "Last 30 days" : "Предходни 30 дена",
     "This year" : "Оваа година",
     "Last year" : "Предходна година",
+    "Between {startDate} and {endDate}" : "Помеѓу {startDate} и {endDate}",
     "Unified search" : "Унифицирано пребарување",
     "Search apps, files, tags, messages" : "Барај апликации, датотеки, ознаки, пораки",
     "Places" : "Места",
     "Date" : "Датум",
+    "Search people" : "Барај луѓе",
     "People" : "Луѓе",
+    "Filter in current view" : "Филтрирај во тековниот приказ",
+    "Search connected services" : "Пребарај во поврзаните сервиси",
     "Results" : "Резултати",
     "Load more results" : "Вчитај повеќе резултати",
     "Search in" : "Барај во",
+    "Partial matches" : "Делумно совпаѓање",
     "Log in" : "Најава",
-    "Logging in …" : "Најава ...",
+    "Logging in …" : "Најавување …",
     "Log in to {productName}" : "Најави се на {productName}",
     "Wrong login or password." : "Погрешно корисничко име или лозинка.",
     "This account is disabled" : "Оваа сметка е оневозможена",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Детектирани се повеќе неуспешни најавувања од вашата IP адреса. Затоа вашиот следен обид за најавување е одложено за 30 секунди.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Премногу неточни обиди за најавување. Обиди се повторно за 30 секунди.",
     "Account name or email" : "Корисничко име или е-пошта",
     "Account name" : "Корисничко име",
     "Server side authentication failed!" : "Автентификацијата на серверската страна е неуспешна!",
     "Please contact your administrator." : "Ве молиме контактирајте го вашиот администратор.",
+    "Session error" : "Грешка во сесијата",
+    "It appears your session token has expired, please refresh the page and try again." : "Се чини дека вашиот токен за сесија е истечен, освежете ја страницата и обидете се повторно.",
     "An internal error occurred." : "Се случи внатрешна грешка.",
     "Please try again or contact your administrator." : "Ве молиме обидете се повторно или контактирајте го вашиот администратор.",
     "Password" : "Лозинка",
+    "Remember me" : "Запамти ме",
     "Log in with a device" : "Најавете се со уред",
     "Login or email" : "Корисничко име или лозинка",
     "Your account is not setup for passwordless login." : "Вашата сметка не е поставена за најавување без лозинка.",
@@ -128,6 +277,7 @@ OC.L10N.register(
     "Passwordless authentication is not supported in your browser." : "Вашиот прелистувач не поддржува автентикација без лозинка.",
     "Reset password" : "Ресетирај лозинка",
     "Back to login" : "Врати се на страната за најавување",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Доколку оваа сметка постои, порака за ресетирање на лозинка е испратена на е-пошта. Доколку не ја добиете, потврдете ја вашата е-пошта и/или коросничко име, проверете во спам/непотребна пошта или побарајте помош од администраторот.",
     "Couldn't send reset email. Please contact your administrator." : "Не можам да истпратам порака за ресетирање. Ве молам контактирајте го вашиот администратор.",
     "Password cannot be changed. Please contact your administrator." : "Лозинката не може да се промени. Ве молам контактирајте го вашиот администратор.",
     "New password" : "Нова лозинка",
@@ -137,22 +287,32 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "Работни задачи & состаноци, синхронизирани со сите ваши уреди.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Чувајте ги вашите колеги и пријатели на едно место без да ги разоткривате нивните приватни информации.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Едноставна апликација за е-пошта интегрирана со Датотеки, Контакти, Календар.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Разговори, видео повици, споделување на екранот, онлајн состаноци и веб конференции - на вашиот компјутер и на вашиот мобилен телефон.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Колаборативни документи, табеларни пресметки и презентации, изградени на Collabora Online.",
+    "Distraction free note taking app." : "Апликација за водење белешки без одвлекување на вниманието.",
     "Recommended apps" : "Препорачани апликации",
-    "Loading apps …" : "Апликациите се вчитуваат ...",
+    "Loading apps …" : "Вчитување апликации …",
     "Could not fetch list of apps from the App Store." : "Неможе да се вчита листата на апликации од продавницата.",
     "App download or installation failed" : "Неуспешно преземање или инсталирање на апликација",
     "Cannot install this app because it is not compatible" : "Неможе да се инсталираа оваа апликација бидејќи не е компатибилна",
     "Cannot install this app" : "Неможе да се инсталираа оваа апликација ",
     "Skip" : "Прескокни",
-    "Installing apps …" : "Инсталирање на апликации ...",
+    "Installing apps …" : "Инсталирање апликации …",
     "Install recommended apps" : "Инсталирајте ги препорачаните апликации",
+    "Online" : "Присутен",
+    "Away" : "Далеку",
+    "Busy" : "Зафатен",
+    "Do not disturb" : "Не вознемирувај",
+    "Mute all notifications" : "Занеми (Mute) ги сите известувања",
+    "Invisible" : "Невидливо",
+    "Appear offline" : "Прикажи исклучен",
     "Avatar of {displayName}" : "Аватар на {displayName}",
     "Settings menu" : "Мени за параметри",
-    "Loading your contacts …" : "Вчитување на вашите контакти ...",
-    "Looking for {term} …" : "Пребарување за {term} …",
+    "Loading your contacts …" : "Вчитување на вашите контакти …",
+    "Looking for {term} …" : "Пребарување за {term} …",
     "Search contacts" : "Пребарување контакти",
     "Reset search" : "Ресетирај пребарување",
-    "Search contacts …" : "Пребарување контакти ...",
+    "Search contacts …" : "Пребарување контакти …",
     "Could not load your contacts" : "Неможат да се вчитаат вашите контакти",
     "No contacts found" : "Не се пронајдени контакти",
     "Show all contacts" : "Прикажи ги сите контакти",
@@ -162,29 +322,62 @@ OC.L10N.register(
     "Press Enter to start searching" : "Притисни Enter за започне пребарувањето",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Внесете најмалку {minSearchLength} карактер за да пребарувате","Внесете најмалку {minSearchLength} карактери или повеќе за да пребарувате"],
     "An error occurred while searching for {type}" : "Настана грешка при пребарување за {type}",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Пребарувањето започнува штом ќе почнете да пишувате, а резултатите може да се добијат со стрелките на тастатурата",
     "Search for {name} only" : "Пребарај само за {name}",
-    "Loading more results …" : "Вчитување на повеќе резултати ...",
+    "Loading more results …" : "Вчитување на повеќе резултати …",
     "Forgot password?" : "Заборавена лозинка?",
     "Back to login form" : "Врати се на формата за најавување",
     "Back" : "Назад",
     "Login form is disabled." : "Формата за најава е оневозможена.",
-    "More actions" : "Повеќе акции",
+    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Формуларот за најавување на Nextcloud е оневозможен. Користете друга опција за најавување доколку е достапна или контактирајте ја вашата администрација.",
+    "Connect to your account" : "Поврзани со вашата сметка",
     "Security warning" : "Безбедносно предупредување",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Доколку не се обидувате да додадете нов уред, некој се обидува да ве надитри и да обезбеди пристап до вашите податоци. Во тој случај не продолжувајте понатаму и веднаш контактирајте го администраторот.",
+    "Alternative log in using app password" : "Алтернативен начин на најава со користење на лозинка за апликација",
+    "Account connected" : "Сметката е поврзана",
+    "Your client should now be connected!" : "Вашиот клиент сега треба да биде поврзан!",
+    "You can close this window." : "Можете да го затворите овој прозорец.",
+    "Account access" : "Пристап до сметка",
+    "More actions" : "Повеќе акции",
+    "User menu" : "Корисничко мени",
+    "Your guest name: {user}" : "Вашето гостинско име: {user}",
+    "You are currently not identified." : "Моментално не сте идентификувани.",
+    "Set public name" : "Постави јавно име",
+    "Change public name" : "Промени јавно име",
+    "Password is too weak" : "Лозинката е премногу слаба",
+    "Password is weak" : "Лозинката е слава",
+    "Password is average" : "Лозинката е просечна",
+    "Password is strong" : "Лозинката е јака",
+    "Password is very strong" : "Лозинката е многу јака",
+    "Password is extremely strong" : "Лозинката е екстремно јака",
+    "Unknown password strength" : "Не е позната јачината на лозинката ",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Вашиот директориум со податоци и датотеки се веројатно достапни преку интенернт поради што <code>.htaccess</code> датотеката не функционира.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "За информации како правилно да го конфигурирате вашиот сервер, ве молиме {linkStart}погледнете ја документацијата{linkEnd}",
+    "Autoconfig file detected" : "Детектирана е автоматска конфигурација",
+    "The setup form below is pre-filled with the values from the config file." : "Формуларот подолу е претходно пополнет со вредностите од конфигурациската датотека.",
+    "Create administration account" : "Создади административна сметка",
+    "Administration account name" : "Име на адмистративна сметка",
+    "Administration account password" : "Лозинка на адмистративна сметка",
     "Storage & database" : "Складиште & база на податоци",
     "Data folder" : "Фолдер со податоци",
+    "Database configuration" : "Конфигурација за база на податоци",
+    "Database type" : "Вид на база на податоци",
+    "Only {firstAndOnlyDatabase} is available." : "Само {firstAndOnlyDatabase} е достапна.",
     "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте дополнителни PHP додатоци за да можете да изберете друг вид на база на податоци.",
     "For more details check out the documentation." : "За повеќе детали проверете ја документацијата.",
     "Performance warning" : "Предупредување за перформансите",
     "You chose SQLite as database." : "Вие избравте SQLite како база на податоци.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за минимални и развојни цели. За користење, препорачуваме различен начин за база на податоци.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ако користите клиент за синхронизација на датотеки, SQLite не е препорачливо.",
+    "Database connection" : "Врска на база на податоци",
     "Database user" : "Корисник на база",
     "Database password" : "Лозинка на база",
     "Database name" : "Име на база",
     "Database tablespace" : "Табела во базата на податоци",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ве молиме, наведете го бројот на портата, заедно со името на серверот (на пример, localhost:5432).",
     "Database host" : "Сервер со база",
-    "Installing …" : "Инсталирање ...",
+    "localhost" : "localhost",
+    "Installing …" : "Инсталирање …",
     "Install" : "Инсталирај",
     "Need help?" : "Ви треба помош?",
     "See the documentation" : "Види ја документацијата",
@@ -193,7 +386,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашиот прелистувач не е поддржан. Надградете на понова или поддржана верзија.",
     "Continue with this unsupported browser" : "Продолжете со овој неподдржан прелистувач",
     "Supported versions" : "Поддржани верзии",
-    "Search {types} …" : "Пребарување {types} …",
+    "Search {types} …" : "Пребарување {types} …",
     "Choose {file}" : "Избери {file}",
     "Choose" : "Избери",
     "Copy to {target}" : "Копирај во {target}",
@@ -213,7 +406,10 @@ OC.L10N.register(
     "(all selected)" : "(сите одбрани)",
     "({count} selected)" : "({count} одбраните)",
     "Error loading file exists template" : "Грешка при вчитување на датотеката, шаблонот постои ",
-    "Saving …" : "Зачувува ...",
+    "Saving …" : "Зачувува  …",
+    "Groups" : "Групи",
+    "Group list is empty" : "Листата во групата е празна",
+    "Unable to retrieve the group list" : "Неможе да се вчита листата со групи",
     "seconds ago" : "пред неколку секунди",
     "Connection to server lost" : "Изгубена е врската со серверот",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при вчитување на страницата, превчитување за %n секунда","Проблем при вчитување на страницата, превчитување за %n секунди"],
@@ -228,14 +424,15 @@ OC.L10N.register(
     "Type to search for existing projects" : "Пребарувај за постоечки проекти",
     "New in" : "Ново во",
     "View changelog" : "Види ги промените",
-    "No action available" : "Нема акции достапни",
-    "Error fetching contact actions" : "Грешка при преземање на контакт",
     "Close \"{dialogTitle}\" dialog" : "Затвори \"{dialogTitle}\"",
+    "Email length is at max (255)" : "Должината на Е-пошта е максимум (255)",
+    "Clipboard not available, please copy manually" : "Клипбоард не е достапен, копирај рачно",
     "Personal" : "Лично",
     "Accounts" : "Сметки",
     "Admin" : "Админ",
     "Help" : "Помош",
     "Access forbidden" : "Забранет пристап",
+    "You are not allowed to access this page." : "Немате дозвола за пристап на оваа страна.",
     "Back to %s" : "Врати се на %s",
     "Page not found" : "Страницата не е пронајдена",
     "The page could not be found on the server or you may not be allowed to view it." : "Страната не е пронајдена на серверот или не ви е дозволен пристап.",
@@ -263,18 +460,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Оди до навигацијата на апликацијата",
     "Go to %s" : "Оди до %s",
     "Get your own free account" : "Креирајте ваша сметка",
-    "Connect to your account" : "Поврзани со вашата сметка",
-    "Please log in before granting %1$s access to your %2$s account." : "Ве молиме најавете се пред да доделите пристап на %1$s во вашата %2$s сметка.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Доколку не се обидувате да додадете нов уред, некој се обидува да ве надитри и да обезбеди пристап до вашите податоци. Во тој случај не продолжувајте понатаму и веднаш контактирајте го администраторот.",
-    "App password" : "Лозинка за апликација",
-    "Grant access" : "Дозволи пристап",
-    "Alternative log in using app password" : "Алтернативен начин на најава со користење на лозинка за апликација",
-    "Account access" : "Пристап до сметка",
-    "Currently logged in as %1$s (%2$s)." : "Најавени сте како %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ќе доделите пристап на %1$s во вашата %2$s сметка.",
-    "Account connected" : "Сметката е поврзана",
-    "Your client should now be connected!" : "Вашиот клиент сега треба да биде поврзан!",
-    "You can close this window." : "Можете да го затворите овој прозорец.",
     "Previous" : "Претходно",
     "This share is password-protected" : "Ова споделување е заштитено со лозинка",
     "The password is wrong or expired. Please try again or request a new one." : "Лозинката е погрешна или е истечена. Ве молиме обидете се повторно или побарајте нова лозинка.",
@@ -314,37 +499,54 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Истанцата %s моментално е во режим на одржување, што значи дека може да потрае некое време.",
     "This page will refresh itself when the instance is available again." : "Оваа веб страница ќе се рефрешира кога истанцата ќе биде повторно достапна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте го вашиот систем администратор до колку оваа порака продолжи да се појавува или пак се појавува ненадејно.",
-    "No temporary profile picture available, try again" : "Не е достапна привремена профилна слика, пробајте повторно",
-    "No crop data provided" : "Не се доставени податоци за сечење",
-    "No valid crop data provided" : "Нема валидни податоци за сечење",
-    "Crop is not square" : "Сечењето не е квадратно",
     "Error occurred while checking server setup" : "Се случи грешка при проверката на параметрите на серверот",
     "For more details see the {linkstart}documentation ↗{linkend}." : "За повеќе детали погледнете во {linkstart}документацијата ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Разговори, видео повици, споделување на екранот, онлајн состаноци и веб конференции - на вашиот компјутер и на вашиот мобилен телефон.",
-    "You have not added any info yet" : "Сè уште немате додадено никакви информации",
-    "{user} has not added any info yet" : "{user} нема додадено никакви информации",
-    "Edit Profile" : "Уреди профил",
-    "The headline and about sections will show up here" : "Насловот и за секциите ќе се појават овде",
+    "unknown text" : "непознат текст",
+    "Hello world!" : "Здраво свету!",
+    "sunny" : "сончево",
+    "Hello {name}, the weather is {weather}" : "Здраво {name}, времето е {weather}",
+    "Hello {name}" : "Здраво {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ова се вашите резултати од пребарувањето<script>alert(1)</script></strong>",
+    "new" : "ново",
+    "_download %n file_::_download %n files_" : ["преземи %n датотека","преземи %n датотеки"],
+    "Direct link copied to clipboard" : "Линкот е копиран во клипборд",
+    "Searching …" : "Пребарување ...",
+    "Logging in …" : "Најава ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Детектирани се повеќе неуспешни најавувања од вашата IP адреса. Затоа вашиот следен обид за најавување е одложено за 30 секунди.",
+    "Loading apps …" : "Апликациите се вчитуваат ...",
+    "Installing apps …" : "Инсталирање на апликации ...",
+    "Loading your contacts …" : "Вчитување на вашите контакти ...",
+    "Looking for {term} …" : "Пребарување за {term} …",
+    "Search contacts …" : "Пребарување контакти ...",
+    "Loading more results …" : "Вчитување на повеќе резултати ...",
+    "Search {types} …" : "Пребарување {types} …",
+    "Saving …" : "Зачувува ...",
     "Very weak password" : "Многу слаба лозинка",
     "Weak password" : "Слаба лозинка",
     "So-so password" : "Така така лозинка",
     "Good password" : "Добра лозинка",
     "Strong password" : "Јака лозинка",
+    "No action available" : "Нема акции достапни",
+    "Error fetching contact actions" : "Грешка при преземање на контакт",
     "Non-existing tag #{tag}" : "Непостоечка ознака #{tag}",
     "Restricted" : "Ограничена",
-    "Invisible" : "Невидливо",
     "Delete" : "Избриши",
     "Rename" : "Преименувај",
     "Collaborative tags" : "Колаборативна ознака",
     "No tags found" : "Не се пронајдени ознаки",
-    "Profile not found" : "Профилот не е пронајден",
-    "The profile does not exist." : "Профилот на постои",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Вашиот директориум со податоци и датотеки се веројатно достапни преку интенернт поради што .htaccess датотеката не функционира.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информации како правилно да го конфигурирате вашиот сервер, ве молиме погледнете ја <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацијата</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Креирај администраторска смета</strong>",
+    "New admin account name" : "Нова администраторска сметка",
+    "New admin password" : "Лозинка на нова администраторска сметка",
     "Show password" : "Прикажи лозинка",
     "Toggle password visibility" : "Вклучи видливост на лозинки",
     "Configure the database" : "Конфигурирај ја базата",
     "Only %s is available." : "Само %s е достапно.",
-    "Direct link copied to clipboard" : "Линкот е копиран во клипборд"
+    "Database account" : "Сметка на база на податоци",
+    "Installing …" : "Инсталирање ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Ве молиме најавете се пред да доделите пристап на %1$s во вашата %2$s сметка.",
+    "Currently logged in as %1$s (%2$s)." : "Најавени сте како %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Ќе доделите пристап на %1$s во вашата %2$s сметка."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
