@@ -206,12 +206,18 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi realizada com sucesso. Por favor, informe este problema para  a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
     "Continue to {productName}" : "Continuar para {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi bem-sucedida. Redirecionando você à {productName} em %n segundo.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n de segundos.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos."],
+    "Done" : "Concluído",
+    "Scan QR code to log in" : "Digitalize o código QR para fazer login",
+    "Use {productName} mobile client you want to connect to scan the code" : "Use o cliente móvel {productName} que você deseja conectar para escanear o código",
+    "Code will expire {timeCountdown} or after use" : "O código expirará {timeCountdown} após o uso",
     "Applications menu" : "Menu de aplicativos",
     "Apps" : "Aplicativos",
     "More apps" : "Mais aplicativos",
     "_{count} notification_::_{count} notifications_" : ["{count} notificação","{count} de notificações","{count} notificações"],
     "No" : "Não",
     "Yes" : "Sim",
+    "App password" : "Senha de aplicativo",
+    "Grant access" : "Conceder acesso",
     "The remote URL must include the user." : "A URL remota deve incluir o usuário.",
     "Invalid remote URL." : "URL remota inválida.",
     "Failed to add the public link to your Nextcloud" : "Falha ao adicionar o link público ao seu Nextcloud",
@@ -248,12 +254,13 @@ OC.L10N.register(
     "Results" : "Resultados",
     "Load more results" : "Carregar mais resultados",
     "Search in" : "Pesquisar em",
+    "Partial matches" : "Correspondências parciais",
     "Log in" : "Entrar",
     "Logging in …" : "Fazendo login …",
     "Log in to {productName}" : "Faça login em {productName}",
     "Wrong login or password." : "Login ou senha incorretos.",
     "This account is disabled" : "Esta conta está desativada",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos várias tentativas de login inválidas de seu IP. Portanto, seu próximo login será desacelerado em até 30 segundos.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Muitas tentativas de login incorretas. Por favor, tente novamente em 30 segundos.",
     "Account name or email" : "Nome da conta ou e-mail",
     "Account name" : "Nome da conta",
     "Server side authentication failed!" : "Autenticação do servidor falhou!",
@@ -326,6 +333,14 @@ OC.L10N.register(
     "Back" : "Voltar",
     "Login form is disabled." : "O formulário de login está desativado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulário de login do Nextcloud está desabilitado. Use outra opção de login, se disponível, ou entre em contato com sua administração.",
+    "Connect to your account" : "Conectar à sua conta",
+    "Security warning" : "Alerta de segurança",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se você não está tentando configurar um novo dispositivo ou aplicativo, alguém está tentando induzi-lo a conceder acesso a seus dados. Nesse caso, não prossiga e entre em contato com o administrador do sistema.",
+    "Alternative log in using app password" : "Login alternativo usando senha do aplicativo",
+    "Account connected" : "Conta conectada",
+    "Your client should now be connected!" : "Seu cliente deve estar conectado agora!",
+    "You can close this window." : "Você pode fechar esta janela.",
+    "Account access" : "Acesso à conta",
     "More actions" : "Mais ações",
     "User menu" : "Menu do usuário",
     "Your guest name: {user}" : "Seu nome de convidado: {user}",
@@ -343,7 +358,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Para obter informações sobre como configurar corretamente seu servidor, {linkStart}consulte a documentação{linkEnd}",
     "Autoconfig file detected" : "Arquivo de configuração automática detectado",
     "The setup form below is pre-filled with the values from the config file." : "O formulário de configuração abaixo é preenchido previamente com os valores do arquivo de configuração.",
-    "Security warning" : "Alerta de segurança",
     "Create administration account" : "Criar conta de administração",
     "Administration account name" : "Nome da conta de administração",
     "Administration account password" : "Senha da conta de administração",
@@ -396,6 +410,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} selecionados)",
     "Error loading file exists template" : "Erro carregando arquivo. Já existe o modelo",
     "Saving …" : "Salvando …",
+    "Groups" : "Grupos",
+    "Group list is empty" : "A lista de grupos está vazia",
+    "Unable to retrieve the group list" : "Não é possível recuperar a lista de grupos",
     "seconds ago" : "segundos atrás",
     "Connection to server lost" : "Conexão perdida com o servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema no carregamento da página, recarregando em %n segundo","Problema no carregamento da página, recarregando em %n de segundos","Problema no carregamento da página, recarregando em %n segundos"],
@@ -446,18 +463,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Pular para a navegação do aplicativo",
     "Go to %s" : "Vá para %s",
     "Get your own free account" : "Obtenha uma conta grátis",
-    "Connect to your account" : "Conectar à sua conta",
-    "Please log in before granting %1$s access to your %2$s account." : "Logue-se antes de conceder acesso %1$s à sua conta %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se você não está tentando configurar um novo dispositivo ou aplicativo, alguém está tentando induzi-lo a conceder acesso a seus dados. Nesse caso, não prossiga e entre em contato com o administrador do sistema.",
-    "App password" : "Senha de aplicativo",
-    "Grant access" : "Conceder acesso",
-    "Alternative log in using app password" : "Login alternativo usando senha do aplicativo",
-    "Account access" : "Acesso à conta",
-    "Currently logged in as %1$s (%2$s)." : "Atualmente logado como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Você irá conceder acesso %1$s à sua conta %2$s.",
-    "Account connected" : "Conta conectada",
-    "Your client should now be connected!" : "Seu cliente deve estar conectado agora!",
-    "You can close this window." : "Você pode fechar esta janela.",
     "Previous" : "Anterior",
     "This share is password-protected" : "Compartilhamento protegido por senha",
     "The password is wrong or expired. Please try again or request a new one." : "A senha está errada ou expirou. Tente novamente ou solicite uma nova.",
@@ -510,6 +515,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Link direto copiado para a área de transferência",
     "Searching …" : "Pesquisando …",
     "Logging in …" : "Entrando …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos várias tentativas de login inválidas de seu IP. Portanto, seu próximo login será desacelerado em até 30 segundos.",
     "Loading apps …" : "Carregando aplicativos...",
     "Installing apps …" : "Instalando aplicativos...",
     "Loading your contacts …" : "Carregando seus contatos...",
@@ -541,6 +547,9 @@ OC.L10N.register(
     "Configure the database" : "Configurar o banco de dados",
     "Only %s is available." : "Somente %s está disponível.",
     "Database account" : "Conta de banco de dados",
-    "Installing …" : "Instalando …"
+    "Installing …" : "Instalando …",
+    "Please log in before granting %1$s access to your %2$s account." : "Logue-se antes de conceder acesso %1$s à sua conta %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Atualmente logado como %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Você irá conceder acesso %1$s à sua conta %2$s."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
