@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Tip fișier necunoscut",
     "An error occurred. Please contact your admin." : "A apărut o eroare. Te rugăm să contactezi administratorul.",
     "Invalid image" : "Imagine invalidă",
-    "No temporary profile picture available, try again" : "Nu este disponibilă nicio imagine temporară a profilului, încearcă din nou",
-    "No crop data provided" : "Nu există informație pentru operațiunea crop",
-    "No valid crop data provided" : "Nu există informație validă pentru operațiunea crop",
-    "Crop is not square" : "Selecția nu este pătrată",
     "State token does not match" : "Statusul token-ului nu se potrivește",
     "Invalid app password" : "Parolă de aplicație invalidă",
     "Could not complete login" : "Nu am putut efectua autentificarea",
@@ -29,6 +25,7 @@ OC.L10N.register(
     "Your login token is invalid or has expired" : "Tokenul tău de autentificare este invalid sau a expirat",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Această versiune produsă de comunitatea Nextcloud nu este suportată și notificările push sunt limitate.",
     "Login" : "Autentificare",
+    "Unsupported email length (>255)" : "Adresa de email este prea lungă (>255)",
     "Password reset is disabled" : "Resetarea parolei este dezactivată.",
     "Could not reset password because the token is expired" : "Nu s-a putut reseta parola deoarece token-ul a expirat",
     "Could not reset password because the token is invalid" : "Nu s-a putut reseta parola deoarece token-ul este invalid",
@@ -38,6 +35,7 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Apăsați butonul următor pentru resetarea parolei dumneavoastră. Dacă nu ați solicitat resetarea parolei, ignorați acest email.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Apăsați link-ul următor pentru resetarea parolei dumneavoastră. Dacă nu ați solicitat resetarea parolei, ignorați acest email.",
     "Reset your password" : "Resetați-vă parola",
+    "The given provider is not available" : "Furnizorul specificat nu este disponibil",
     "Task not found" : "Sarcina nu a fost găsită",
     "Internal error" : "Eroare internă",
     "Not found" : "Nu a fost găsit",
@@ -49,16 +47,17 @@ OC.L10N.register(
     "No translation provider available" : "Niciun furnizor de traducere nu este disponibil",
     "Could not detect language" : "Nu a putut fi detectată limba",
     "Unable to translate" : "Nu s-a putut traduce",
-    "Nextcloud Server" : "Nextcloud Server",
-    "Some of your link shares have been removed" : "Unele dintre link-urile tale partajate au fost șterse",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Din cauza unui bug de securitate, a trebuit să eliminăm unele dintre link-urile dvs. partajate. Vă rugăm să consultați link-ul pentru mai multe informații.",
-    "Learn more ↗" : "Află mai multe ↗",
-    "Preparing update" : "Se pregătește actualizarea",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Etapa de reparare:",
     "Repair info:" : "Informații despre reparații:",
     "Repair warning:" : "Avertisment de reparație:",
     "Repair error:" : "Eroare de reparare:",
+    "Nextcloud Server" : "Nextcloud Server",
+    "Some of your link shares have been removed" : "Unele dintre link-urile tale partajate au fost șterse",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Din cauza unui bug de securitate, a trebuit să eliminăm unele dintre link-urile dvs. partajate. Vă rugăm să consultați link-ul pentru mai multe informații.",
+    "The account limit of this instance is reached." : "Limita contului a fost atinsă.",
+    "Learn more ↗" : "Află mai multe ↗",
+    "Preparing update" : "Se pregătește actualizarea",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Utilizează actualizarea din linie de comandă, pentru că actualizarea automată este dezactivată în config.php.",
     "Turned on maintenance mode" : "Modul mentenanță a fost activat",
     "Turned off maintenance mode" : "Modul mentenanță a fost dezactivat",
@@ -75,16 +74,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatibil)",
     "The following apps have been disabled: %s" : "Următoarele aplicații au fost dezactivate: %s",
     "Already up to date" : "Deja actualizat",
-    "Error occurred while checking server setup" : "A apărut o eroare la verificarea configurației serverului",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Pentru mai multe detalii vedeți {linkstart}documentația ↗{linkend}.",
-    "unknown text" : "text necunoscut",
-    "Hello world!" : "Hello world!",
-    "sunny" : "însorit",
-    "Hello {name}, the weather is {weather}" : "Bună {name}, vremea este {weather}",
-    "Hello {name}" : "Salut {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Acestea sunt rezultatele căutării tale<script>alert(1)</script></strong>",
-    "new" : "nou",
-    "_download %n file_::_download %n files_" : ["descarcă %n fișier","descarcă %n fișiere","descarcă %n fișiere"],
+    "Unknown" : "Necunoscut",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Actualizarea este în desfășurare, părăsirea acestei pagini ar putea întrerupe procesul în anumite medii.",
     "Update to {version}" : "Actualizare la {version}",
     "An error occurred." : "A apărut o eroare.",
@@ -93,19 +83,21 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Actualizarea nu a reușit. Te rugăm să raportezi această problemă <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunității Nextcloud</a>.",
     "Continue to {productName}" : "Continuă la {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Actualizare efectuată. Redirectare la {productName} în %n secundă.","Actualizare efectuată. Redirectare la {productName} în %n seconde.","Actualizare efectuată. Redirectare la {productName} în %n secunde."],
+    "Done" : "Realizat",
     "Applications menu" : "Meniul aplicațiilor",
     "Apps" : "Aplicații",
     "More apps" : "Mai multe aplicatii",
     "_{count} notification_::_{count} notifications_" : ["{count} notificare","{count} notificări","{count} notificări"],
     "No" : "Nu",
     "Yes" : "Da",
+    "App password" : "Parolă aplicație",
+    "Grant access" : "Permite accesul",
     "Failed to add the public link to your Nextcloud" : "Eroare la adăugarea link-ului public la Nextcloud",
     "Custom date range" : "Interval particular de date",
     "Pick start date" : "Selectează o dată de început",
     "Pick end date" : "Selectează o dată de sfârșit",
     "Search in date range" : "Caută în intervalul",
     "Search everywhere" : "Caută oriunde",
-    "Searching …" : "Căutare ...",
     "Start typing to search" : "Tastați pentru căutare",
     "No matching results" : "Niciun rezultat găsit",
     "Today" : "Azi",
@@ -124,14 +116,10 @@ OC.L10N.register(
     "Load more results" : "Încarcă mai multe rezultate",
     "Search in" : "Caută în",
     "Log in" : "Autentificare",
-    "Logging in …" : "Se autentifică...",
     "Log in to {productName}" : "Logare la {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Au fost detectate mai multe încercări de logare eșuate de la adresa dumneavoastră IP. De aceea, următoarea încercare va fi încetinită până la 30 de secunde.",
     "Account name or email" : "Cont utilizator sau email",
     "Server side authentication failed!" : "Autentificarea la nivel de server a eșuat!",
     "Please contact your administrator." : "Contactează-ți administratorul.",
-    "Temporary error" : "Eroare temporară",
-    "Please try again." : "Încercați din nou.",
     "An internal error occurred." : "A apărut o eroare internă.",
     "Please try again or contact your administrator." : "Încearcă din nou sau contactează-ți administratorul.",
     "Password" : "Parolă",
@@ -155,21 +143,19 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documente colaborative, foi de calcul și prezentări, create în Collabora Online.",
     "Distraction free note taking app." : "Aplicație simplă pentru note",
     "Recommended apps" : "Aplicații recomandate",
-    "Loading apps …" : "Se încarcă aplicațiile ...",
     "Could not fetch list of apps from the App Store." : "Nu s-a putut prelua lista aplicațiilor din App Store.",
     "App download or installation failed" : "Descărcarea și instalarea aplicației a eșuat",
     "Cannot install this app because it is not compatible" : "Nu se poate instala aplicația deoarece este incompatibilă",
     "Cannot install this app" : "Nu se poate instala această aplicație",
     "Skip" : "Sari peste",
-    "Installing apps …" : "Se instalează aplicațiile ...",
     "Install recommended apps" : "Instalați aplicațiile recomandate",
+    "Away" : "Departe",
+    "Busy" : "Ocupat",
+    "Invisible" : "Invizibil",
     "Avatar of {displayName}" : "Avatarul {displayName}",
     "Settings menu" : "Meniul Setări",
-    "Loading your contacts …" : "Se încarcă contactele ...",
-    "Looking for {term} …" : "Se caută  {term} …",
     "Search contacts" : "Cautare contacte",
     "Reset search" : "Resetează căutarea",
-    "Search contacts …" : "Caută contacte ...",
     "Could not load your contacts" : "Nu pot încarca contactele",
     "No contacts found" : "Nu s-au găsit contacte",
     "Show all contacts" : "Arată toate contactele",
@@ -181,13 +167,18 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Eroare la căutarea pentru {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Căutarea începe când tastați și navigarea în rezultate se face cu tastele săgeți",
     "Search for {name} only" : "Caută doar {name} ",
-    "Loading more results …" : "Se încarcă mai multe rezultate ...",
     "Forgot password?" : "Ai uitat parola?",
     "Back to login form" : "Înapoi la forma de login",
     "Back" : "Înapoi",
     "Login form is disabled." : "Forma de login este dezactivată.",
-    "More actions" : "Mai multe acțiuni",
+    "Connect to your account" : "Conectează-te la contul tău",
     "Security warning" : "Alertă de securitate",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Dacă încercați să configurați un nou device sau o aplicație, cineva încearcă să vă păcălească să-i acordați accesul la date. În acest caz nu continuați și contactați în schimb administratorul.",
+    "Account connected" : "Cont conectat",
+    "Your client should now be connected!" : "Clientul dumneavoastră ar trebui să fie conectat acum!",
+    "You can close this window." : "Puteți închide această fereastră.",
+    "Account access" : "Acces cont",
+    "More actions" : "Mai multe acțiuni",
     "Storage & database" : "Stocare și baza de date",
     "Data folder" : "Director date",
     "Install and activate additional PHP modules to choose other database types." : "Instalează și activează module PHP adiționale pentru a putea alege alte tipuri de baze de date.",
@@ -202,7 +193,6 @@ OC.L10N.register(
     "Database tablespace" : "Tabela de spațiu a bazei de date",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifică și numărul portului pe lângă hostname (ex: localhost;5432).",
     "Database host" : "Bază date",
-    "Installing …" : "Se instalează ...",
     "Install" : "Instalează",
     "Need help?" : "Ai nevoie de ajutor?",
     "See the documentation" : "Vezi documentația",
@@ -211,7 +201,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Browserul este incompatibil. Faceți upgrade la o versiune nouă.",
     "Continue with this unsupported browser" : "Continuă cu browserul incompatibil",
     "Supported versions" : "Versiuni compatibile",
-    "Search {types} …" : "Căutare {types} …",
     "Choose {file}" : "Selectați {file}",
     "Choose" : "Alege",
     "Copy to {target}" : "Copiază la {target}",
@@ -231,7 +220,9 @@ OC.L10N.register(
     "(all selected)" : "(toate selectate)",
     "({count} selected)" : "({count} selectate)",
     "Error loading file exists template" : "Eroare la încărcarea fișierelor șablon",
-    "Saving …" : "Se salvează",
+    "Groups" : "Grupuri",
+    "Group list is empty" : "Lista de grupuri este goală",
+    "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
     "seconds ago" : "secunde în urmă",
     "Connection to server lost" : "S-a pierdut conexiunea la server",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleme la încărcarea paginii, se reîncarcă într-o secundă","Probleme la încărcarea paginii, se reîncarcă în câteva secunde","Probleme la încărcarea paginii, se reîncarcă în %n secunde"],
@@ -246,24 +237,15 @@ OC.L10N.register(
     "Type to search for existing projects" : "Tastați pentru căutarea proiectelor",
     "New in" : "Nou în",
     "View changelog" : "Vezi changelog",
-    "No action available" : "Nici o acțiune disponibilă",
-    "Error fetching contact actions" : "A apărut o eroare la preluarea activităților privind contactele",
     "Close \"{dialogTitle}\" dialog" : "Închide dialogul \"{dialogTitle}\"",
-    "Non-existing tag #{tag}" : "Etichetă inexistentă #{tag}",
-    "Restricted" : "Restricționat",
-    "Invisible" : "Invizibil",
-    "Delete" : "Șterge",
-    "Rename" : "Redenumește",
-    "Collaborative tags" : "Etichete colaborative",
-    "No tags found" : "Nu au fost găsite etichete",
     "Personal" : "Personal",
     "Accounts" : "Conturi",
     "Admin" : "Administrator",
     "Help" : "Ajutor",
     "Access forbidden" : "Acces restricționat",
+    "Back to %s" : "Înapoi la %s",
     "Page not found" : "Pagina nu a fost găsită",
     "The page could not be found on the server or you may not be allowed to view it." : "Pagina nu există pe server sau nu aveți permisiunea de a o vedea.",
-    "Back to %s" : "Înapoi la %s",
     "Too many requests" : "Prea multe cereri",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Prea multe cereri din această rețea. Încercați mai târziu sau contactați administratorul.",
     "Error" : "Eroare",
@@ -287,17 +269,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Salt la navigatorul aplicației",
     "Go to %s" : "Salt la %s",
     "Get your own free account" : "Obțineți contul personal gratuit",
-    "Connect to your account" : "Conectează-te la contul tău",
-    "Please log in before granting %1$s access to your %2$s account." : "Trebuie să vă logați înainte de a permite accesul %1$s la contul dumneavoastră %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Dacă încercați să configurați un nou device sau o aplicație, cineva încearcă să vă păcălească să-i acordați accesul la date. În acest caz nu continuați și contactați în schimb administratorul.",
-    "App password" : "Parolă aplicație",
-    "Grant access" : "Permite accesul",
-    "Account access" : "Acces cont",
-    "Currently logged in as %1$s (%2$s)." : "Autentificat ca %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ești pe cale să permiți %1$s accesul la %2$s contul tău.",
-    "Account connected" : "Cont conectat",
-    "Your client should now be connected!" : "Clientul dumneavoastră ar trebui să fie conectat acum!",
-    "You can close this window." : "Puteți închide această fereastră.",
     "Previous" : "Precedentul",
     "This share is password-protected" : "Această partajare este protejată cu parolă",
     "The password is wrong or expired. Please try again or request a new one." : "Parola este greșită sau a expirat. Încercați din nou sau solicitați actualizarea acesteia.",
@@ -336,27 +307,50 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Instanța %s este acum în modul de mentenanță, ceea ce ar putea dura o vreme.",
     "This page will refresh itself when the instance is available again." : "Această pagină se va actualiza automat când instanța va fi disponibilă din nou.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactează-ți administratorul de sistem dacă acest mesaj persistă sau a apărut neașteptat.",
-    "Currently open" : "Deschise curent",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, apeluri video, partajare ecran, întâlniri online și videoconferințe - în browser și cu aplicația mobilă.",
-    "You have not added any info yet" : "Nu ați adăugat nicio informație",
-    "{user} has not added any info yet" : "{user} nu a adăugat nicio informație",
-    "Error opening the user status modal, try hard refreshing the page" : "Eroare la deschiderea status utilizator, încercați refresh",
-    "Edit Profile" : "Editare profil",
-    "The headline and about sections will show up here" : "Secțiunile titlu și despre vor fi afișate aici",
-    "Error loading message template: {error}" : "Eroare la încărcarea şablonului de mesaje: {error}",
+    "Error occurred while checking server setup" : "A apărut o eroare la verificarea configurației serverului",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Pentru mai multe detalii vedeți {linkstart}documentația ↗{linkend}.",
+    "unknown text" : "text necunoscut",
+    "Hello world!" : "Hello world!",
+    "sunny" : "însorit",
+    "Hello {name}, the weather is {weather}" : "Bună {name}, vremea este {weather}",
+    "Hello {name}" : "Salut {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Acestea sunt rezultatele căutării tale<script>alert(1)</script></strong>",
+    "new" : "nou",
+    "_download %n file_::_download %n files_" : ["descarcă %n fișier","descarcă %n fișiere","descarcă %n fișiere"],
+    "Searching …" : "Căutare ...",
+    "Logging in …" : "Se autentifică...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Au fost detectate mai multe încercări de logare eșuate de la adresa dumneavoastră IP. De aceea, următoarea încercare va fi încetinită până la 30 de secunde.",
+    "Loading apps …" : "Se încarcă aplicațiile ...",
+    "Installing apps …" : "Se instalează aplicațiile ...",
+    "Loading your contacts …" : "Se încarcă contactele ...",
+    "Looking for {term} …" : "Se caută  {term} …",
+    "Search contacts …" : "Caută contacte ...",
+    "Loading more results …" : "Se încarcă mai multe rezultate ...",
+    "Search {types} …" : "Căutare {types} …",
+    "Saving …" : "Se salvează",
     "Very weak password" : "Parolă foarte slabă",
     "Weak password" : "Parolă slabă",
     "So-so password" : "Parolă medie",
     "Good password" : "Parolă bună",
     "Strong password" : "Parolă puternică",
-    "Profile not found" : "Profil inexistent",
-    "The profile does not exist." : "Profilul nu există",
+    "No action available" : "Nici o acțiune disponibilă",
+    "Error fetching contact actions" : "A apărut o eroare la preluarea activităților privind contactele",
+    "Non-existing tag #{tag}" : "Etichetă inexistentă #{tag}",
+    "Restricted" : "Restricționat",
+    "Delete" : "Șterge",
+    "Rename" : "Redenumește",
+    "Collaborative tags" : "Etichete colaborative",
+    "No tags found" : "Nu au fost găsite etichete",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Directorul tău de date și fișiere sunt probabil accesibile de pe Internet, deoarece fișierul .htaccess nu funcționează.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pentru informații despre configurarea corectă a serverului, vedeți <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentația</a>.",
     "Show password" : "Arată parola",
     "Toggle password visibility" : "Vizibilitate parolă",
     "Configure the database" : "Configurează baza de date",
     "Only %s is available." : "Doar %s este disponibil.",
-    "Database account" : "Cont bază de date"
+    "Database account" : "Cont bază de date",
+    "Installing …" : "Se instalează ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Trebuie să vă logați înainte de a permite accesul %1$s la contul dumneavoastră %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Autentificat ca %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Ești pe cale să permiți %1$s accesul la %2$s contul tău."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
