@@ -206,12 +206,15 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uygulama güncellenemedi. Lütfen bu sorunu <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud topluluğuna</a> bildirin.",
     "Continue to {productName}" : "{productName} ile ilerle",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz.","Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz."],
+    "Done" : "Tamam",
     "Applications menu" : "Uygulamalar menüsü",
     "Apps" : "Uygulamalar",
     "More apps" : "Diğer uygulamalar",
     "_{count} notification_::_{count} notifications_" : ["{count} bildirim","{count} bildirim"],
     "No" : "Hayır",
     "Yes" : "Evet",
+    "App password" : "Uygulama parolası",
+    "Grant access" : "Erişim izni ver",
     "The remote URL must include the user." : "Uzak adreste kullanıcı bulunmalıdır.",
     "Invalid remote URL." : "Uzak adres geçersiz.",
     "Failed to add the public link to your Nextcloud" : "Herkese açık bağlantı Nextcould üzerine eklenemedi",
@@ -248,12 +251,13 @@ OC.L10N.register(
     "Results" : "Sonuçlar",
     "Load more results" : "Diğer sonuçları yükle",
     "Search in" : "Şurada aransın",
+    "Partial matches" : "Bir parçası uyanlar",
     "Log in" : "Oturum aç",
     "Logging in …" : "Oturum açılıyor…",
     "Log in to {productName}" : "{productName} oturumu aç",
     "Wrong login or password." : "Hatalı kullanıcı adı ya da parolası.",
     "This account is disabled" : "Bu hesap kullanımdan kaldırılmış",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "IP adresinizden yapılan birden çok geçersiz oturum açma girişimi algılandı. Bu nedenle oturum açmanız 30 saniye süreyle engellendi.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Çok sayıda başarısız oturum açma denemesi yapıldı. Lütfen 30 saniye sonra yeniden deneyin.",
     "Account name or email" : "Hesap adı ya da e-posta adresi",
     "Account name" : "Hesap adı",
     "Server side authentication failed!" : "Kimlik sunucu tarafında doğrulanamadı!",
@@ -326,6 +330,14 @@ OC.L10N.register(
     "Back" : "Geri",
     "Login form is disabled." : "Oturum açma formu kullanımdan kaldırılmış.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud oturum açma formu kullanımdan kaldırılmış. Varsa başka bir oturum açma seçeneğini kullanın ya da yöneticiniz ile görüşün.",
+    "Connect to your account" : "Hesabınızı bağlayın",
+    "Security warning" : "Güvenlik uyarısı",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Yeni bir aygıt ya da uygulama kurmaya çalışmıyorsanız, başka biri verilerinize erişmek için sizi kandırmaya çalışıyor. Durum buysa daha ileri gitmeyin ve sistem yöneticiniz ile görüşün.",
+    "Alternative log in using app password" : "Uygulama parolası ile alternatif oturum açma",
+    "Account connected" : "Hesap bağlandı",
+    "Your client should now be connected!" : "İstemciniz şimdi bağlantı kurmuş olmalı!",
+    "You can close this window." : "Bu pencereyi kapatabilirsiniz.",
+    "Account access" : "Hesap erişimi",
     "More actions" : "Diğer işlemler",
     "User menu" : "Kullanıcı menüsü",
     "Your guest name: {user}" : "Konuk adınız: {user}",
@@ -343,7 +355,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Sunucunuzu nasıl yapılandıracağınız hakkında bilgi almak için {linkStart}belgelere bakabilirsiniz{linkEnd}",
     "Autoconfig file detected" : "Otomatik yapılandırma dosyası bulundu",
     "The setup form below is pre-filled with the values from the config file." : "Aşağıdaki kurulum formu, yapılandırma dosyasındaki değerlerle önceden doldurulmuştur.",
-    "Security warning" : "Güvenlik uyarısı",
     "Create administration account" : "Yönetici hesabı oluştur",
     "Administration account name" : "Yönetici hesabı kullanıcı adı",
     "Administration account password" : "Yönetici hesabı parolası",
@@ -396,6 +407,9 @@ OC.L10N.register(
     "({count} selected)" : "({count} seçilmiş)",
     "Error loading file exists template" : "Dosya var kalıbı yüklenirken sorun çıktı",
     "Saving …" : "Kaydediliyor…",
+    "Groups" : "Gruplar",
+    "Group list is empty" : "Grup listesi boş",
+    "Unable to retrieve the group list" : "Grup listesi alınamadı",
     "seconds ago" : "saniye önce",
     "Connection to server lost" : "Sunucu bağlantısı kesildi",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek","Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek"],
@@ -446,18 +460,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Uygulama gezinmesine geç",
     "Go to %s" : "%s bölümüne git",
     "Get your own free account" : "Ücretsiz hesabınızı açın",
-    "Connect to your account" : "Hesabınızı bağlayın",
-    "Please log in before granting %1$s access to your %2$s account." : "Lütfen %1$s için %2$s hesabınıza erişim izni vermeden önce oturum açın.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Yeni bir aygıt ya da uygulama kurmaya çalışmıyorsanız, başka biri verilerinize erişmek için sizi kandırmaya çalışıyor. Durum buysa daha ileri gitmeyin ve sistem yöneticiniz ile görüşün.",
-    "App password" : "Uygulama parolası",
-    "Grant access" : "Erişim izni ver",
-    "Alternative log in using app password" : "Uygulama parolası ile alternatif oturum açma",
-    "Account access" : "Hesap erişimi",
-    "Currently logged in as %1$s (%2$s)." : "%1$s (%2$s) olarak oturum açıldı.",
-    "You are about to grant %1$s access to your %2$s account." : "%1$s için %2$s hesabınıza erişim izni vermek üzeresiniz.",
-    "Account connected" : "Hesap bağlandı",
-    "Your client should now be connected!" : "İstemciniz şimdi bağlantı kurmuş olmalı!",
-    "You can close this window." : "Bu pencereyi kapatabilirsiniz.",
     "Previous" : "Önceki",
     "This share is password-protected" : "Bu paylaşım parola korumalı",
     "The password is wrong or expired. Please try again or request a new one." : "Parola hatalı ya da geçerlilik süresi dolmuş. Lütfen yeniden deneyin ya da parolanızı değiştirin. ",
@@ -510,6 +512,7 @@ OC.L10N.register(
     "Direct link copied to clipboard" : "Doğrudan bağlantı panoya kopyalandı",
     "Searching …" : "Aranıyor…",
     "Logging in …" : "Oturum açılıyor …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "IP adresinizden yapılan birden çok geçersiz oturum açma girişimi algılandı. Bu nedenle oturum açmanız 30 saniye süreyle engellendi.",
     "Loading apps …" : "Uygulamalar yükleniyor …",
     "Installing apps …" : "Uygulamalar kuruluyor …",
     "Loading your contacts …" : "Kişileriniz yükleniyor …",
@@ -541,6 +544,9 @@ OC.L10N.register(
     "Configure the database" : "Veri tabanını yapılandır",
     "Only %s is available." : "Yalnızca %s kullanılabilir.",
     "Database account" : "Veri tabanı hesabı",
-    "Installing …" : "Kuruluyor…"
+    "Installing …" : "Kuruluyor…",
+    "Please log in before granting %1$s access to your %2$s account." : "Lütfen %1$s için %2$s hesabınıza erişim izni vermeden önce oturum açın.",
+    "Currently logged in as %1$s (%2$s)." : "%1$s (%2$s) olarak oturum açıldı.",
+    "You are about to grant %1$s access to your %2$s account." : "%1$s için %2$s hesabınıza erişim izni vermek üzeresiniz."
 },
 "nplurals=2; plural=(n > 1);");
